#!/bin/sh
#
# $Id: nightly_dods_build.sh,v 1.1.2.6 2002/04/24 23:29:19 jimg Exp $
#
# Perform a nightly build of the dods code in $DODS_ROOTS. Each
# directory listed in DODS_ROOTS should be the root directory of DODS
# C++ code checked out from CVS. The script will update the code
# getting the latest changes and run make.

# Read the site-specific configuration information. CVS holds an example of
# this file in n ightly_dods_build.conf.example. Rename the file to remove
# `.example' and edit for your site. 
source nightly_dods_build.conf

host_full=`hostname`
host=`echo $host_full | sed 's/\([^\.]*\)\..*/\1/'`

for d in $DODS_ROOTS
do
    target=World
    build=`basename $d`
    make_log=${host}.${build}.${target}.`date +%Y.%m.%d`

    if ! cd $d
    then
	echo
	echo "Could not cd to $d" > $make_log
	echo
	exit
    fi

    echo "Build of ${build} using ${target} on `date`" > $make_log
    echo "Built on ${host_full} (`uname -a`)" >> $make_log

    echo "__________ make distclean & grammarclean ______________" >> $make_log
    $MAKE distclean >> $make_log 2>&1
    (cd src/dap && $MAKE grammarclean >> $make_log 2>&1)

    echo "__________ cvs update _________________________________" >> $make_log
    cvs -z3 update -d -P >> $make_log 2>&1
    
    echo "__________ configure __________________________________" >> $make_log
    ./configure >> $make_log 2>&1

    echo "__________ make ${target} _____________________________" >> $make_log
    $MAKE $target >> $make_log 2>&1

    echo "__________ make binary-tar_____________________________" >> $make_log
    $MAKE binary-tar >> $make_log 2>&1

    echo "__________ make check _________________________________" >> $make_log
    $MAKE check >> $make_log 2>&1

    echo "_______________________________________________________" >> $make_log
    echo "Build completed at `date`." >> $make_log 2>&1

    # if [ $? -ne 0 ] # This didn't work. jhrg 2001/10/04
    if grep '\*\*\*' $make_log | grep -v 'No rule to make target .*\.  Stop'
    then
	echo
	echo "make World on $host in $d reports errors!"
	echo

	mail -s "make World on $host in $d reports errors!" $developers <<EOF
Check $url_for_logs for a complete
report of nightly builds. The target $build, $target reports errors; see
$make_log and search for three asterisks (\*\*\*) in a row.
EOF
    fi

    mv $make_log $new_logs_directory
    old=`find $new_logs_directory -ctime +10`
    if test -n "$old"
    then
        mv $old $old_logs_archive
    fi
done

# $Log: nightly_dods_build.sh,v $
# Revision 1.1.2.6  2002/04/24 23:29:19  jimg
# I modified the test used to figure out if an error occurred so that code
# which has no Makefile does not get flagged as an error (but it will still
# show up in the logs with three asterisks). The updated configure scripts
# should all be set so that if the program/component cannot be built, no
# Makefile is created.
#
# Revision 1.1.2.5  2002/04/17 23:21:42  jimg
# Added a time/date stamp to the end of the build.
#
# Revision 1.1.2.4  2002/04/12 23:05:53  jimg
# Moved the configuration information to a separate file which this script
# sources. That way simple fixes in this script can easily be used by all the
# builds. The information that's specific to a given site is held in
# nightly_dods_build.conf; there's and example conf file with the additional
# extension '.example'.
#
# Revision 1.1.2.3  2002/04/12 18:17:28  jimg
# Added the DODS_ROOTS variable to the `Set configuration parameters' section
# of the script. If you fail to set this, the script fails mysteriously.
#
# Revision 1.1.2.2  2002/04/12 18:02:48  jimg
# Added variables to make configuration of the log's destination directories
# easier. I also consolidated the configuration information at the front of the
# script (hopefully continuing the work that Ethan did).
#
