function [url, loaddodsbool, URLinfo, pcc_times, depths, lats, lons, ...
      num_url] = gbcat(getarchive, getranges, getmode, getvars)
%
%    This function is supposed to be a generic cat function
%

% The preceding empty line is important

% $Id: gbcat.m,v 1.1 2002/04/15 20:04:57 dan Exp $
% klee 08/2000

% should be passed out in different name  !!!!!
global urlinfolist

if exist(getarchive) == 2   
  eval(getarchive)
else
  dodsmsg('Metadata not found!')
  return
end

% Initialize variables.
% ----- note that both urlinfolist and defaults are structs -----
url = [];  loaddodsbool = 0;  num_url = 0;  
lats = [];  lons = [];  depths = [];  pcc_times = [];  

% ADVANTAGES OF SETTING UP URLINFOLIST AS STRUCT: 
%     EASY TO ADD NEW FIELDS AND VALUES AS NEEDED
%     NO CONSTRAINT ON SIZES AND TYPES

urlinfolist = []; 
urlinfolist(1).issequence = 1;

% Need to get essential information from both archive.m and data 
%     which includes, variable names
%                     dependencies (levels) when necessary
%                     varbool (value specified, function specified)
%                     infotext
if exist('CatalogServer')
  if ~isempty(CatalogServer) & ~isnan(CatalogServer)
    urlinfolist(1).catserver_info = CatalogServer;
    [urlinfolist] = getinfo(getarchive,getmode,urlinfolist);
  end
elseif exist('Server')
  if ~isempty(Server) & ~isnan(Server)
    urlinfolist(1).catserver_info = [];
    urlinfolist(1).server_info = Server;
    [urlinfolist] = getinfo(getarchive,getmode,urlinfolist);
  end
end
% fixed missing field 2001/01/17 -- dbyrne
urlinfolist(1).inven_info(1:4) = 0;

%%%%%%%%%%%%%%%%%%
% GET NAMES
% Suppose time name (TimeName) are in the following order:
%     year,month,day,yrday,julianday,decimaldate,hr,min,sec,othert
%     totaly 10 of them
% Suppose latitutde and longitude has only one name available
% Suppose depth name is in the following order:
%     mdepth (measured in water), wdepth (water depth), 
%     mpressure (measured in air), height (inst height), 
%     otherd (such as for model depth)
varnames = [];  sumt = 0;
xName = [];  yName = [];  zName = [];  timeName = [];
if isfield(urlinfolist, 'var_name')
  varnames = urlinfolist(1).var_name;
else
  break
end
xName = varnames(1,:);  yName = varnames(2,:);  zName = varnames(3:7,:);
timeName = varnames(8:17,:);
sumt = urlinfolist(2).var_name(4);
%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%
% GET VALUES
% in case there's additional value provided out of data file, or via a function
%%% if isFunction,  varbool == 2;  ex., dyear = 'monthly' or dyear = 'TimeInfo_File';
%%% if isValue,     varbool == 1;  ex., dyear = [1994.1, 1994.2, 1994.3];
% if noValue,     varbool == 0;  ex., TimeName = 'dyear';
% if nothing,     varbool == nan;ex., TimeName = '';
varbool = [];
varbool = urlinfolist(1).var_info;
%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%
% EVALUATE DEPENDENCY
% Assming that dependency is based on the following order:
%     time -> geolocation -> dpeth/pressure  
%
% isindep is the catagory of indep var
isindep = [];
isindep = urlinfolist(2).depend_info;
%%%%%%%%%%%%%%%%%%

      
%%%%%%%%%%%%%%%%%%
% -----  GET CATURLLIST  -----
caturllist = [];  urllist = [];  catfix = []; callstr = [];

% FIRST, if dependency is 'all', fire up first cat request
% --  if there's CatalogServer exist, otherwise, CatServer == Server and 
%         there's only one Server available
if ~isempty(urlinfolist(1).catserver_info)
  [urlinfolist] = getcat(getarchive,getranges,varnames,urlinfolist);
end
      

% -----  GET SELECTION  -----
% First, check out if there's any Info_File
% Note: Info_File should return the following information:
%    timestr:    time string used to construct url
%    servers:    server string used to construct url
%    times:      value of time in decimal_year if loaddods is called within or 
%                    default values are returned
%    urlinfolist:
%       urlinfolist.catserver_info: cat server being selected, as url strings
%         * urlinfolist(1).catserver_info:  CatalogServer name 
%         * urlinfolist(2).catserver_info:  Start_ and End_ in CE 
%         * urlinfolist(3).catserver_info:  DODS_Min_ and DODS_Max_ in CE 
%           * (1:4) is in the order of x/y/depth/height or other depth *
%         * urlinfolist(4).catserver_info:  Cat str (jgofs, time, etc) 
%       urlinfolist.server_info:    servers being selected, as url strings
%         * urlinfolist(1).server_info:  Server
%         * note that server may be equal to catserver for a single file dataset 
%         * urlinfolist(2).server_info:  server number (which server)
%       urlinfolist.baseserver_info:original servers from get cat, w/o expanding
%       urlinfolist.url_info:       final fully constraint url list 
%         * (servers + projection + selection) 
%       urlinfolist.selection_info: selection strings
%         * urlinfolist(1).selection_info = timestr
%         * urlinfolist(2).selection_info = geostr
%         * urlinfolist(3).selection_info = depthstr
%       urlinfolist.depend_info:    dependencies between xdim/ydim/zdim/time
%         * urlinfolist(1).depend_info:  catagories for cat server 
%         * urlinfolist(2).depend_info:  catagories for data server
%       urlinfolist.time_info:      extra time info, such as bounding for servers
%         * urlinfolist(1).time_info:  StartTime or single time from Cat return
%         * urlinfolist(2).time_info:  EndTime, if applied
%         * urlinfolist(3).time_info:  otherTime being converted to decimal_year
%                                      ex.  gsodtime converts CompTime to dy
%         * urlinfolist(4).time_info:  used by yrday, to hold year info
%         * urlinfolist(5).time_info:  recal time after geturl is called
%       urlinfolist.ydim_info:      extra lat info, see getcat.m for cat detail
%       urlinfolist.xdim_info:      extra lon info, see getcat.m for cat detail
%       urlinfolist.zdim_info:      extra depth info, see getcat.m for cat detail
%       urlinfolist.var_info:       varbool
%         * urlinfolist(1).var_info:  varbool
%         * urlinfolist(2).var_info:  DodsName/SelectableVariables ratio
%         * urlinfolist(3).var_info:  reassess indicator, 1 if all returned vars
%                                     (during getdata) have to be reassessed
%                                     (ex. frontal dataset)
%       urlinfolist.tmp_var_info:   temp varbool for either get_url or get_data
%       urlinfolist.var_name:       varnames
%         * urlinfolist(1).var_name:  DodsName 
%         * urlinfoilst(2).var_name:  [0 0 zindex tindex(the sumt)] 
%       urlinfolist.tmp_var_name:   temp varnames for either get_url or get_data
%       urlinfolist.returned_var:   if returned_var needs
%                                      to be treated other than default
%       urlinfolist.varorder_info   used by gburl.m, ordering of time/xdim/ydim/zdim if
%                                      variable(s) is multi-dimensional
%       urlinfolist.starttoend      starttoend for server optimization
%       urlinfollist.issequence     sequence data indicator
%       urlinfolist.sizeindex_info: size of each url_info, or more presicely,
%                                      size of corrected returned time,
%                                      and index of start and end index
%       urlinfolist.infotext        used to be the infotext, any text needs to be 
%                                     promped to the users
%       urlinfolist.newvars         if urlinfolist(3).var_info == 1, new var 
%                                     values are stored here
%       urlinfolist.inven_info:     for optimization for jgofs inventory calls
%                                     1 to 4 is x/y/z/t
% Note: The use of Info_File for FF array data is to be replaced by the upcoming
%    multi-dimentional reform in the GUI. 

% initialization 
timestr = [];  geostr = [];  depthstr = [];  serverstr = [];
tmptimes = [];  tmplats = [];  tmplons = [];  tmpdepths = [];  servers = [];

% loop through time/zdim/xdim/ydim
done = 0;   % for lat and lon
first = 0;  % return from indep var and pass server_info to urlinfolist
varargin = [];
for i = [4,3,2,1]
  if i == 1 
    if ~done
      if exist('GeoInfo_File') == 1
	if exist(GeoInfo_File) == 2
	  eval(['[geostr,servers,tmplats,tmplons,urlinfolist] = ',...
		GeoInfo_File,'(''url'',getarchive,getranges,getmode,getvars,' ...
		'urlinfolist,varargin);']);
	end
      else
	[geostr,serverstr,urlinfolist] = getgstr('url',...
	    getarchive,getranges,urlinfolist);
      end
      done = 1;
    end
    first = first + 1;
  elseif i == 2
    if ~done
      if exist('GeoInfo_File') == 1
	if exist(GeoInfo_File) == 2
	  eval(['[geostr,servers,tmplats,tmplons,urlinfolist] = ',...
		GeoInfo_File,'(''url'',getarchive,getranges,getmode,getvars,' ...
		'urlinfolist,varargin);']);
	end
      else
	[geostr,serverstr,urlinfolist] = getgstr('url',...
	    getarchive,getranges,urlinfolist);
      end
      done = 1;
    end
    first = first + 1;
  elseif i == 3
    if exist('DepthInfo_File') == 1
      if exist(DepthInfo_File) == 2
	eval(['[depthstr,servers,tmpdepths,urlinfolist] = ',DepthInfo_File,...
	      '(''url'',getarchive,getranges,getmode,getvars,urlinfolist,' ...
	      'varargin);']);
      end
    else
      [depthstr,serverstr,urlinfolist,varargout] = getdstr('url',...
	  getarchive,getranges,urlinfolist);
    end
    first = first + 1;
  elseif i == 4
    if exist('TimeInfo_File') == 1
      if exist(TimeInfo_File) == 2
	eval(['[timestr,servers,tmptimes,urlinfolist] = ',TimeInfo_File,...
	      '(''url'',getarchive,getranges,getmode,getvars,urlinfolist,' ...
	      'varargin);']);
      end
    else
      [urlinfolist,timestr,serverstr] = gettstr('url',getarchive,...
	  getranges,urlinfolist);
    end
    first = first + 1;
  end
  % if urlinfolist.server_info is not yet assigned ....
  if first == 1
    if ~isfield(urlinfolist, 'server_info')
      if ~isempty(serverstr),  urlinfolist(1).server_info = serverstr;
      elseif ~isempty(servers),  urlinfolist(1).server_info = servers;
      elseif ~isempty(Server),  urlinfolist(1).server_info = Server;
      end
    end
  end
end
% reassign varbool and varnames in case there're changes
%     made in Info_Files
% NOTE that it is made effectively for the entire process,
%     namely get_detail, get_data, all the way down to data
%     return.  If only temp change is needed (for server
%     opt etc.), assign it in urlinfolist(1).tmp_var_name 
%     and leave the formal one untouched.
if isfield(urlinfolist, 'tmp_var_name')
  if ~isempty(urlinfolist(1).tmp_var_name)
    varnames = urlinfolist(1).tmp_var_name;
  end
else
  varnames = urlinfolist(1).var_name;
end
if isfield(urlinfolist, 'tmp_var_info')
  if ~isempty(urlinfolist(1).tmp_var_info)
    varbool = urlinfolist(1).tmp_var_info;
  end
else
  varbool = urlinfolist(1).var_info;
end

% -----   GET PROJECTION   -----
returned_var = [];
if isfield(urlinfolist, 'returned_var')
  returned_var = urlinfolist(1).returned_var;
elseif ~isempty(timestr) | ~isempty(geostr) | ~isempty(depthstr)
  for i = 1:length(varbool)
    if ~isnan(varbool(i))
      if ~varbool(i)
        returned_var = [returned_var, deblank(varnames(i,:)), ','];
      end
    end
  end
  % drop the last comma
  returned_var = returned_var(1:length(returned_var)-1);
  % if there're only commas and no real varnames, set returned_var back to null
  if length(findstr(returned_var, ',')) == length(returned_var)
    returned_var = [];
  end
end
urlinfolist(1).returned_var = returned_var;

% -----  DECOMPOSE STRs AND SERVERs  -----
% first, check if urlinfolist.server_info exist
serverlist = [];  baseurllist = [];  qmark = [];
urlinfolist(1).selection_info = timestr;
urlinfolist(2).selection_info = geostr;
urlinfolist(3).selection_info = depthstr;
if ~isempty(urlinfolist(1).server_info)
  serverlist = urlinfolist(1).server_info;
  % second, check if all serverlist and strs are the same size
  if (size(serverlist,1) == size(timestr,1)) & ...
    (size(timestr,1) == size(geostr,1)) & ...
    (size(timestr,1) == size(depthstr,1))
    for i = 1:size(serverlist,1)
      strs = [deblank(timestr(i,:)), deblank(geostr(i,:)), ...
              deblank(depthstr(i,:))];
      qmark = findstr(serverlist(i,:), '?');
      if isempty(qmark)
        % if the server is a straight url without constraint
        if ~findstr(strs, '   ')
          baseurllist = strvcat(baseurllist, [deblank(serverlist(i,:)), '?',...
                                returned_var, strs]);
        else
          baseurllist = strvcat(baseurllist, [deblank(serverlist(i,:)), '?',...
                                returned_var, strrep(strs,'   ','')]);
        end
      else
        % if the server looks like '...?mooring=135'
        tmpserverlist = serverlist(i,1:qmark);
        tmpconst = serverlist(i,qmark+1:length(serverlist(i,:)));
        if ~findstr(strs, '   ')
          baseurllist = strvcat(baseurllist, [tmpserverlist, returned_var,...
                                strs, tmpconst]);
        else
          baseurllist = strvcat(baseurllist, [tmpserverlist, returned_var, ...
                                strrep(strs,'   ',''), tmpconst]);
        end
      end
    end
  elseif (isempty(timestr) & isempty(geostr) & isempty(depthstr))
    for i = 1:size(serverlist,1)
      qmark = findstr(serverlist(i,:), '?');
      if isempty(qmark)
        baseurllist = strvcat(baseurllist, [deblank(serverlist(i,:)), ...
			      '?',returned_var]);
      else
        tmpserverlist = serverlist(i,1:qmark);
        tmpconst = serverlist(i,qmark+1:length(serverlist(i,:)));
        baseurllist = strvcat(baseurllist, [tmpserverlist, returned_var,...
                              tmpconst]);
      end
    end
  end
end
urlinfolist(1).url_info = baseurllist;
%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%
% GET DATA AND RETURN   --   here, instead of in get function
keep = zeros(size(baseurllist,1),1);

%first, eval all vars to be empty!!!!!
for i = 1:size(varnames,1)
  if ~varbool(i),  eval([deblank(varnames(i,:)), ' = [];']);  end
end
warningstr = [];

% First, find out which var is supposed to be returned from loaddods call
timebool = [];  xbool = [];  ybool = [];  zbool = [];
timebool = varbool(8:17); 
xbool = varbool(1); ybool = varbool(2); zbool = varbool(3:7);
timevarindex = [1:length(timebool)]; 
zvarindex = [1:length(zbool)];
if any(isnan(timevarindex)),  timevarindex = find(~isnan(timebool));  end
if any(isnan(zvarindex)),  zvarindex = find(~isnan(zbool));  end
timevarindex = find(timebool == 0);
zvarindex = find(zbool == 0);

dods_err = 0;  isjg = 0;  call = 1; tmp = [];
% Based on 3 scenarios:
%    Cat -> 2nd Cat -> GetData (specifically for jg multiobjects)
%                                    (Is it jgofs only?)
%    Cat ->         -> GetData
%           Server  -> GetData (Server only, both get_detail and get_data
%                               access the same server)   
if ~isempty(strisin(baseurllist, 'nph-jg')), isjg = 1;  end
if ~isempty(urlinfolist(1).catserver_info)
  if ~isjg,  call = 0;  end
end

% added on 12/12/2000 for compatibility with loaddods w/o -A option
if exist('Cat2ndCall') == 1
  if ~Cat2ndCall, call = 0;  end
end

tmptheurl = [];
for i = 1:size(baseurllist,1)
  if ~isempty(returned_var) 
    % If there's a need for the second call
    if call

    %%if isjg | isempty(urlinfolist(1).catserver_info)
      theurl = deblank(baseurllist(i,:));
      tmptheurl = theurl;

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %12/28/2000
      % Optimization for jgofs inventory calls goes here.
      % It is disable until GUI can handle a straight line for start and end
      %     values.
      % It is a quick and short fix, just strip out the ones that don't need
      repstr = [];  tmpstr = [];  tmp = []; ap = [];
      %urlinfolist(1).inven_info(1:4) = 0;
      tmptheurl = theurl;
      if exist('Inven_Infostr') == 1 & exist('Inven_Infonum') == 1
        if ~isempty(Inven_Infostr)
          % A flag to pass back to get function indicating the need.
          % note that the order of 1 to 4 is x/y/z/t
          for k = 1:4
            if any(Inven_Infonum == k), urlinfolist(1).inven_info(k) = k; end
          end 
          for k = 1:size(Inven_Infostr,1)
            repstr = deblank(Inven_Infostr(k,:));
            % replacing in selection part
            tmp = findstr(tmptheurl, ['&',repstr]);
            ap = findstr(tmptheurl, '&');
            while ~isempty(tmp)
              if ~isempty(find(ap > tmp(1)))
                if ap(min(find(ap > tmp(1)))) < length(tmptheurl)
                  tmpstr = tmptheurl(tmp(1):ap(min(find(ap > tmp(1))))-1);
                else
                  tmpstr = tmptheurl(tmp(1):length(tmptheurl));
                end
              else
                tmpstr = tmptheurl(tmp(1):length(tmptheurl));
              end
              tmptheurl = strrep(tmptheurl, tmpstr, '');
              tmp = findstr(tmptheurl, ['&',repstr]);
              ap = findstr(tmptheurl, '&');
            end
            % replacing in projection part
            tmptheurl = strrep(tmptheurl, [',',repstr], '');
            tmptheurl = strrep(tmptheurl, repstr, '');
          end
        end
      end
      if ~isempty(findstr(tmptheurl, '&'))
        if any(findstr(tmptheurl, '&') == 1)
          % indicating there's only selection left, no projection,
          %     no need to call
          tmptheurl = [];
        end
      end
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

      if ~isempty(tmptheurl)
        if findstr(tmptheurl, 'nph-jg')
          % NOTE -F IS STILL USED HERE, SHOULD MOVE THE FUNCTIONALITY TO 
          %     ANCILLARY  LATER 
          urlstr = ['loaddods(''-F -e'',''',tmptheurl,''')'];
          eval(urlstr);
        else
          loaddods('-e', tmptheurl);  
        end 
      end                     
    end
  end

  if dods_err == 1
    % PCC added the following to soften the blow on 2/4/02
    % Guessing that the following message means that server failed, not answering.
    imtch = findstr( dods_err_msg, 'Error: Fatal Error: operation failed (0)'); 
    if ~isempty(imtch)
      imtch = findstr( URL, '?');
      if isempty(imtch)
        imtch = length(URL) + 1;
      end
      base_URL = URL(1:imtch-1);
      dds_URL = strcat( base_URL, '.dds');
      dods_err_msg = sprintf('%s\n\n%s\n%s\n%s\n\n\%s', ...
        '           >>>>>>>> ERROR IN DODS DATA ACQUISITION <<<<<<<<', ...
        dods_err_msg, ...
        '  It is likely that the server is not responding. You might try', ...
        '  the following URL in your browser to see if it is alive:', ...
         dds_URL);
    else
      dods_err_msg = sprintf('%s\n%s', ...
        '           >>>>>>>> ERROR IN DODS DATA ACQUISITION <<<<<<<<', ...
        dods_err_msg);
    end
    % End PCC additions/modifications
    break
  else
    timetemp = [];  e = [];
    e = find(varbool == 0);

    % If tmptheurl is empty, no call is being issued.
    if ~isempty(tmptheurl)
      if ~isempty(e),  varvalue = eval(deblank(varnames(e(1),:)));  
      else,  varvalue = -1;   end
    else
      varvalue = 1;
    end

    %%if any(~isnan(varvalue)) | isempty(returned_var) 
    % assumes loaddods returns nan for null data from jgofs server
    if any(~isnan(varvalue)) | isempty(returned_var) | ~call
      num_url = num_url + 1;
      keep(i) = 1;      % indicator of a working url

      %   -------------   times  ----------------
      decimaldates = [];    timevar = [];   tmpi = [];
      if exist('TimeInfo_File') == 1
        if exist(TimeInfo_File) == 2
          if ~isempty(tmptimes),  decimaldates = tmptimes;
          else      
            for j = 1:size(timeName,1)
              if ~isempty(deblank(timeName(j,:)))
                if exist(deblank(timeName(j,:))) == 1
                  tmp = eval(deblank(timeName(j,:)));
                  timevar{j} = tmp;
                end
              end
            end
            varargin = varargin(1:length(varargin)-1);
            eval(['[timestr,servers,tmptimes,urlinfolist] = ',TimeInfo_File,...
              '(''recal'',getarchive,getranges,getmode,getvars,urlinfolist,' ...
              'timevar);']);
            decimaldates = tmptimes;
          end
        end
      %%elseif ~isempty(timevarindex)
      elseif ~isempty(timevarindex) & call
        switch sumt
          % SHOULD I USE DIFFERENT MODE IN GETDATE_XXX, OR CODE IT HERE?
          case 0,   % nothing specified
            decimaldates = [];
          case 7,   % year/month/day
            theindex = [1 2 3];
            tmpindex = isin(theindex, timevarindex);
            tmpindex = theindex(find(tmpindex));
            timevar1 = [];  timevar2 = [];  timevar3 = [];
            for j = 1:3
              if tmpindex(j)
                % only eval the ones with bool value equals 0 
	        tmp = eval(deblank(timeName(tmpindex(j),:)));
	        eval(['timevar',num2str(j),' = tmp;'])
              end
            end
            if ~isempty(timevar1) | ~isempty(timevar2) | ~isempty(timevar3)
              % whether all(varbool == 0) or has defaults or returned from date 
              %     function
              % note that the 'empty' here means value does not exist in 
              %     the workspace
              [urlinfolist,decimaldates] = getd7('recal',getarchive,...
                   getranges,str2mat(timeName(1,:),timeName(2,:),...
                   timeName(3,:)),varbool,urlinfolist,timevar1,timevar2,...
                   timevar3);
            end
	  case 8,   % yrday only
            % set default as the first year selected
            years = floor(getranges(4,1));
	    if isfield(urlinfolist, 'time_info')
              if ~isempty(urlinfolist(4).time_info)
                years = urlinfolist(4).time_info;
              end
            end
            yeardays = 365 + isleap(years);
            decimaldates = [decimaldates; years(i) + ...
                            (eval(deblank(timeName(4,:)))/yeardays(i))];
          case 9,   % year/yrday
	    theindex = [1 4];
            tmpindex = isin(theindex, timevarindex);
            tmpindex = theindex(find(tmpindex));
            timevar1 = [];  timevar2 = [];
            for j = 1:2
              if tmpindex(j)
                tmp = eval(deblank(timeName(tmpindex(j),:)));
                eval(['timevar',num2str(j),' = tmp;']) 
              end
            end
            if ~isempty(timevar1) | ~isempty(timevar2)
              [urlinfolist,decimaldates] = getd9('recal',getarchive,...
                   getranges,str2mat(timeName(1,:),timeName(4,:)),varbool,...
                   urlinfolist,timevar1,timevar2);
            end
          case 32,  % decimaldate
            decimaldates = eval(deblank(timeName(6,:)));
          case 272, % julianday/sec
            theindex = [5,9];
            tmpindex = isin(theindex, timevarindex);
            tmpindex = theindex(find(tmpindex));
            timevar1 = [];  timevar2 = [];
            for j = 1:2
              if tmpindex(j)
                tmp = eval(deblank(timeName(tmpindex(j),:)));
                eval(['timevar',num2str(j),' = tmp;']) 
              end
            end
            if ~isempty(timevar1) | ~isempty(timevar2)
              [urlinfolist,decimaldates] = getd272('recal',getarchive,...
                   getranges,str2mat(timeName(5,:),timeName(9,:)),varbool,...
                   urlinfolist,timevar1,timevar2);
              decimaldates = varargout{1};
            end
        end    % end of switch sumt
      else
        % from first cat or as default
        tmpt = [];
        if isfield(urlinfolist, 'baseserver_info')
          for k = 1:size(urlinfolist(1).baseserver_info,1)
            if strcmp(deblank(urlinfolist(1).server_info(i,:)), ...
                      deblank(urlinfolist(1).baseserver_info(k,:)))
              for m = 1:size(urlinfolist(1).time_info,2)
                tmpt = [tmpt; urlinfolist(m).time_info(k)];
              end
            end
          end
        end
	decimaldates = tmpt;
      end
      % Because, if request from 1998/10/05:12:00:00 to 1999/01/01:12:00:00,
      %     and the dataset is selected by year/month/day, the real request
      %     goes from 1998/10/05 to 1999/01/01, while the real one is 12 hrs
      %     passes 1998/10/05 and 1999/01/01.  
      %     As consequence, any return of the day of 1998/10/05 is excluded 
      %     in this manner (or the asteries on time axis would be over the 
      %     selected boundaries)
      tmpi = find(decimaldates >= getranges(4,1) & ...
                  decimaldates <= getranges(4,2));
      %%if ~isempty(tmp)
      %%  urlinfolist(1).sizeindex_info(num_url) = length(tmp);
      %%  urlinfolist(2).sizeindex_info(num_url,1) = min(tmp);
      %%  urlinfolist(2).sizeindex_info(num_url,2) = max(tmp);
      %%  times = [times; decimaldates(tmp)];
      %%end

      %   -------------   xdim/ydim  ----------------
      tmpx = [];  tmpy = [];  tmpxx = [];  tmpyy = [];
      xdim = 0;  ydim = 0;
      if isfield(urlinfolist, 'xdim_info'), xdim = 1;  end
      if isfield(urlinfolist, 'ydim_info'), ydim = 1;  end
      if any([ybool xbool] == 0) & call
        if ybool == 0 & xbool == 0
          tmpx = eval(xName);
          tmpy = eval(yName); 
          if isjg
            if ~isempty(tmpi), tmpx = tmpx(tmpi); tmpy = tmpy(tmpi); end
          end
        elseif ybool == 1 & xbool == 0
          tmpx = eval(xName);
          if isjg
            if ~isempty(tmpi), tmpx = tmpx(tmpi);  end   %12/28/2000
          end
          if ydim
            if ~isempty(urlinfolist(1).ydim_info) 
              if isfield(urlinfolist, 'baseserver_info')
                for k = 1:size(urlinfolist(1).baseserver_info,1)
                  if strcmp(deblank(urlinfolist(1).server_info(i,:)), ...
                            deblank(urlinfolist(1).baseserver_info(k,:)))
                    tmpy = [tmpy, urlinfolist(1).ydim_info(k)];
                  end
                end
              end
            end
          end             
        elseif ybool == 0 & xbool == 1
          tmpy = eval(yName);
          if isjg
            if ~isempty(tmpi), tmpy = tmpy(tmpi);  end   %12/28/2000
          end
          if xdim
            if ~isempty(urlinfolist(1).xdim_info)
              if isfield(urlinfolist, 'baseserver_info')
                for k = 1:size(urlinfolist(1).baseserver_info,1)
                  if strcmp(deblank(urlinfolist(1).server_info(i,:)), ...
                            deblank(urlinfolist(1).baseserver_info(k,:)))
                    tmpx = [tmpx, urlinfolist(1).xdim_info(k)];
                  end
                end
              end
            end
          end
        end
      else
	if ydim
          if ~isempty(urlinfolist(1).ydim_info)
            if isfield(urlinfolist, 'baseserver_info')
              for k = 1:size(urlinfolist(1).baseserver_info,1)
                if strcmp(deblank(urlinfolist(1).server_info(i,:)), ...
                          deblank(urlinfolist(1).baseserver_info(k,:)))
                  tmpy = [tmpy, urlinfolist(1).ydim_info(k)];
                end
              end
            end
          else,  tmpy = tmplats;  end
        else,  tmpy = tmplats;  end
        if xdim
          if ~isempty(urlinfolist(1).xdim_info)
            if isfield(urlinfolist, 'baseserver_info')
              for k = 1:size(urlinfolist(1).baseserver_info,1)
                if strcmp(deblank(urlinfolist(1).server_info(i,:)), ...
                          deblank(urlinfolist(1).baseserver_info(k,:)))
                  tmpx = [tmpx, urlinfolist(1).xdim_info(k)];
                end
              end
            end
	  else,  tmpx = tmplons;  end
        else,  tmpx = tmplons;  end
      end
      %%lats = [lats; tmpy];
      %%lons = [lons; tmpx];

      %   -------------   zdim  ----------------
      tmpz = [];
      depthvar1 = []; depthvar2 = []; depthvar3 = []; depthvar4 = []; 
      depthvar5 = []; 
      dvar1 = []; dvar2 = []; dvar3 = []; dvar4 = []; dvar5 = [];
      if ~isempty(zvarindex) & call
        for j = 1:length(zvarindex)
          if zvarindex(j)
            tmp = eval(deblank(zName(zvarindex(j),:)));
            eval(['depthvar',num2str(zvarindex(j)),' = tmp;']);  
          end
        end
        [depthstr,serverstr,urlinfolist,dvar1,dvar2,dvar3,dvar4,dvar5] = ...
             getdstr('recal',getarchive,getranges,urlinfolist,...
             depthvar1,depthvar2,depthvar3,depthvar4,depthvar5);
        for k = [1 3 5]
          tmptmpz = [];
          tmptmpz = eval(['dvar',num2str(k)]);
          if ~isempty(tmptmpz),  tmpz = [tmpz; tmptmpz];  end
        end
      else
	if isfield(urlinfolist, 'zdim_info')
          if ~isempty(urlinfolist(1).zdim_info) | ...
             ~isempty(urlinfolist(3).zdim_info)
            if isfield(urlinfolist, 'baseserver_info')
              for k = 1:size(urlinfolist(1).baseserver_info,1)
                if strcmp(deblank(urlinfolist(1).server_info(i,:)), ...
                          deblank(urlinfolist(1).baseserver_info(k,:)))
                  if ~isempty(urlinfolist(2).depend_info)
                    if any(urlinfolist(2).depend_info == 3)
                      for m = [1,3,5]
                        if ~isempty(deblank(zName(m,:)))
                          tmpz = [tmpz; urlinfolist(m).zdim_info(k)]; 
                        end
                      end
                    elseif any(urlinfolist(1).depend_info > 2 & ...
                               urlinfolist(1).depend_info < 4)
                      tmpz = [tmpz; urlinfolist(1).zdim_info(k)];
                    end
                  else
                    % zdim_info exists, but zdim_info somehow was not captured
                    %     while getinfo
                    %     Cat whatever in zdim_info to tmpz 
                    tmpz = [tmpz; urlinfolist(1).zdim_info(k)];
                  end
                end
              end
            end
          else,  tmpz = [tmpz; tmpdepths];  end            
        else
          tmpz = [tmpz; tmpdepths];
        end
      end
      %%depths = [depths; tmpz];

      % Guard against null return from loaddods call.
      %     It returns zero instead of NaN for version of 3.1.8 and above.
      allzeros = 0;
      if ~isempty(decimaldates)
        if all(decimaldates == 0), allzeros(4) = 1; end
      end
      if ~isempty(tmpx)
        if all(tmpx == 0), allzeros(1) = 1; end
      end
      if ~isempty(tmpy)
        if all(tmpy == 0), allzeros(2) = 1; end
      end
      if ~isempty(tmpz)
        if all(tmpz == 0), allzeros(3) = 1; end
      end
      if all(allzeros == 1)
        num_url = num_url - 1;
        keep(i) = 0;      % indicator of a working url
        tmpz = [];  tmpy = [];  tmpx = [];  decimaldates = [];
      else
        depths = [depths; tmpz];
        lats = [lats; tmpy];
        lons = [lons; tmpx];
        if ~isempty(tmpi)
          urlinfolist(1).sizeindex_info(num_url) = length(tmpi);
          urlinfolist(2).sizeindex_info(num_url,1) = min(tmpi);
          urlinfolist(2).sizeindex_info(num_url,2) = max(tmpi);
          pcc_times = [pcc_times; decimaldates(tmpi)];
        end
      end      

    end          % end of if varvalue(1) > 1e-10 | varvalue(1) == 0
  end          % end of if dods_err
end          % end of for i = 1:size(baseurllist,1)


baseurllist = baseurllist(find(keep),:);
urlinfolist(1).keep_info = keep;
% note that the server_info and catserver_info has been set up 
url = urlinfolist(1).catserver_info;
URLinfo = urlinfolist;
%%%%%%%%%%%%%%%%%%

return

% $Log: gbcat.m,v $
% Revision 1.1  2002/04/15 20:04:57  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.12  2002/04/11 16:23:02  dan
% Change times to pcc_times to avoid problem with times operator.
%
% Revision 1.11  2002/02/08 23:01:52  dan
% Added text to the dialog box that comes up on a loaddods error
% saying that it is likely that the server is down and suggesting
% how to check this.
%
% Revision 1.10  2001/01/18 18:52:55  dbyrne
%
%
% fixed some minor bugs, changed input/output args to include URLinfo.
% -- dbyrne 01/01/18
%
% Revision 1.9  2000/12/29 00:39:09  kwoklin
% Fix some bugs found for previous fix (revision 1.8).
% Add jgofs inventory optimization code.  To disable/enable the optimization,
% use Inven_Infostr and Inven_Infonum in the archive.m files.  klee
%
% Revision 1.8  2000/12/27 21:07:24  kwoklin
% Safeguard loaddods return for jgofs server. It returns zero instead
% of NaN for no-data-exist.   klee
%
% Revision 1.7  2000/12/19 15:55:49  kwoklin
% Add Cat2ndCall for compatibility with loaddods w/o -A option. klee
%
% Revision 1.6  2000/12/19 15:24:11  kwoklin
% Fix a conditional problem on zdim.   klee
%
% Revision 1.5  2000/12/06 19:11:47  kwoklin
% Wrap up Umbrella variable. Fix call error in gbcat.  klee
%
% Revision 1.4  2000/12/05 18:01:46  kwoklin
% Fix typos in epstruct, derefdat, gettstr and getjgsta.
% Fix returned argout6 to catserver in gbcat.
% Differentiate depth and heigth in getcat and getinfo.
% Add string building functionality in gburl for focus data set.  klee
%
% Revision 1.3  2000/11/14 19:21:24  kwoklin
% Minor update for usgsts and nmfscur data sets.  klee
%
% Revision 1.2  2000/11/02 16:04:20  kwoklin
% Adding data reeval after returned from get_data call (mainly for frontal
% data sets). Modify gbcat and gburl accordingly (more ad hoc implementations).
% klee
%
% Revision 1.1  2000/09/19 20:50:41  kwoklin
% First toolbox internal release.   klee
%
