%
%  Georges Bank Neil Brown CTD Data

% The preceding empty line is important
% $Id: gbnfctd.m,v 1.1 2002/04/15 20:04:57 dan Exp $
% klee 08/2000
% klee 03/1999

GetFunctionName = 'getjgsta';
CatalogServer = 'http://dods.gso.uri.edu/cgi-bin/nph-ff/catalog/gbnfctd.dat';
Cat_m_File = 'gbcat';
URL_m_File = 'gburl';
Catvars = str2mat('DODS_URL','DODS_Min_Latitude','DODS_Max_Latitude','DODS_Min_Longitude','DODS_Max_Longitude','DODS_Min_Depth','DODS_Max_Depth');
Catselc = str2mat('date_range');
Catstr = 'jgofs';
%Inven_Infostr = str2mat('press');
%Inven_Infonum = 3;
%urlinfolist(2).infotext = ['The data set is sampling at approximately every 1 meter. Please note that there will not be any asterisks shown up on the zdim-line of the browser, but there is still some data available for the interval.'];

LonRange = [-71.41 -65.62];
LatRange = [40.28 42.37];
TimeRange = [1992.39059645 1994.5698];
DepthRange = [0.0 300];
Resolution = nan;

DataName = 'Water Column - Georges Bank CTD Data - NMFS/GLOBEC';    
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName = str2mat('year','','','yrday1_gmt','','','','','','');         
DepthName = str2mat('press','','','','');
DepthUnits = 'Meters';
DodsName = str2mat('temp','sal','flvolt');
SelectableVariables = str2mat('Sea_Temp','Salinity','Fluorescence');
OptionalVariables = str2mat('eventno','cast');
SelectableOptional = str2mat('Event_No','Cast');

Acknowledge = [];
Data_Use_Policy = sprintf('%s' ,...
      'Any person making substantial use of a data set must communicate with the investigators who acquired the data prior to publication and anticipate that the data collectors will be co-authors of published results. This extends to model results and to data organized for retrospective studies. (Please refer to U.S. GLOBEC''s data policy Report #10 (http://cbl.umces.edu/fogarty/usglobec/reports/datapol/ datapol.contents.html).) The data available here are intended for scholarly use by the academic and scientific community, with the express understanding that any such use will properly acknowledge the originating investigator. Use or reproduction of any material herein for any commercial purpose is prohibited without prior written permission from the U.S. GLOBEC Georges Bank Data Management Office. (http://globec.whoi.edu/globec-dir/contact_dmo.html)');

%COMMENTS
Comments1 = sprintf('%s\n', ...
'                            Georges Bank CTD Data              ',...
'   ',...
'                   Parameter         Description                    Units',...
'                 ----------------------------------------------------------',...
'                   year              2-digit year (92,93,94,or 95)  year',...
'                   ship              1st letter in ship name        character',...
'                   instrument        "ctd_nb"(nbrown) or "ctd_sb" (seabird)   ',...
' pi                1st initial & last name (jmanning)               name',...
' eventno           event number  (al14594.001)                      nd',...
' gyd_range         gmt yearday range for particular event           decimayd:decyd',...
' lyd_range         local yearday range for particular event         decimayd:decyd',...
' lon_range         longtitude range for particular event            decdeg:decdeg',...
' lat_range         lattitude range for particular event             decdeg:decdeg',...
' CTD_range         range of CTD cast #''s in event                   cast#:cast#',...
' sd_range          max sample depth range for  event                meters:meters',...
' CTD_range         range of CTD cast #''s in event                   cast#:cast#',...
' oper              operation number (transect, grid, bongo)         code 1,2 3',...
' oper_num          consecutive operation of this type               integer',...
' site              designated site (mixed, strat, drifter)          text descript.',...
' comments          comments                                         text descript.',...
' gyd               gmt yearday                                      decimal yd',...
' lyd               local yd                                         local yd',...
' cast              cast #                                           integer',...
' lon               longitude                                        decimal degrees',...
' lat               latitude                                         decimal degrees',...
' press             pressure                                         meters',...
' temp              temperature                                      degC',...
' sal               salinity                                         PSU',...
' flvolt            fluorescence                                     volts ',...
'   ',...
'The WHOI/Millard/Limeburner CTD processing routines were used on 1995 data. ',...
'They are calibrated with Niskin bottles. The salt correction and rms differences are posted ',...
'at the top of each data file. Prior to 1995, the data posted here is preliminary General ',...
'Oceanics CTDPOST output and did not require a salt correction (<0.01 psu mean difference).');

Comments4 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: May. 22, 1992 (1992.39059645)', ...
'         Ending_Date:    May. 25, 1995 (1995.39713644)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 71.4190 W ', ...
'              East Bounding Coordinate: 65.6177 W ', ...
'              South Bounding Coordinate: 40.2875 N ', ...
'              North Bounding Coordinate: 42.3604 N ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               James Manning', ...
'               NMFS',...
'               Woods Hole, MA 02543',...
'               USA ', ...
'               Electronic Mail Address:INTERNET > jmanning@whsun1.wh.whoi.edu',...
'               FAX: 508-495-2258 ',...
'         Address - globec: ',...
'               Robert Groman',...
'               Swift House MS# 38',...
'               Woods Hole, MA 02543-1127',...
'               USA ',...
'               Electronic Mail Address:INTERNET > rgroman@whoi.edu',...
'               FAX: (508) 457-2169',...
'         Address - dods: ',...
'               Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments4];


% $Log: gbnfctd.m,v $
% Revision 1.1  2002/04/15 20:04:57  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.3  2000/12/29 00:43:44  kwoklin
% Add Inven_Infostr and Inven_Infonum for jgofs inventory optimization.  klee
%
% Revision 1.2  2000/12/21 16:40:16  kwoklin
% Add Catvars, Catselc, Catstr and uncommand Time/Lon/Lat names for
% compatibility with loaddods w/o -A option.  If the option is used,
% Catxxx should be commanded out.                              klee
%
% Revision 1.1  2000/09/19 20:50:41  kwoklin
% First toolbox internal release.   klee
