%
%  GLOBEC Seward Johnson CTD Cast Dataset

% The preceding empty line is important
% $Id: gbsjctd.m,v 1.1 2002/04/15 20:04:58 dan Exp $
% klee 09/2000
% klee 04/1999

GetFunctionName = 'getjgsta';
CatalogServer = 'http://dods.gso.uri.edu/cgi-bin/nph-ff/catalog/gbsjctd.dat';
Cat_m_File = 'gbcat';
URL_m_File = 'gburl';
Catvars = str2mat('DODS_URL','DODS_Min_Latitude','DODS_Max_Latitude','DODS_Min_Longitude','DODS_Max_Longitude','DODS_Min_Depth','DODS_Max_Depth');
Catselc = str2mat('date_range');
Catstr = 'jgofs';

LonRange = [-67.8 -67.1];
LatRange = [40.4 41.5];
TimeRange = [1995.318 1995.458];
DepthRange = [0.0 162.0];
Resolution = nan;

DataName = 'Water Column - Seward Johnson CTD Data - URI/GLOBEC';    
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName = 'yrday_gmt';         
DepthName = 'press';
DepthUnits = 'dbar';
DodsName = str2mat('temp','sal','sigma_t');
SelectableVariables = str2mat('Sea_Temp','Salinity','Sigma_t');
OptionalVariables = 'station';
SelectableOptional = 'Station';

%correspond to [t,x,y,d,...]
DataScale = [1995 1/365; nan nan; nan nan; nan nan; nan nan; nan nan; nan nan; nan nan; nan nan];

Acknowledge = [];
Data_Use_Policy = sprintf('%s' ,...
      'Any person making substantial use of a data set must communicate with the investigators who acquired the data prior to publication and anticipate that the data collectors will be co-authors of published results. This extends to model results and to data organized for retrospective studies. (Please refer to U.S. GLOBEC''s data policy Report #10 (http://cbl.umces.edu/fogarty/usglobec/reports/datapol/ datapol.contents.html).) The data available here are intended for scholarly use by the academic and scientific community, with the express understanding that any such use will properly acknowledge the originating investigator. Use or reproduction of any material herein for any commercial purpose is prohibited without prior written permission from the U.S. GLOBEC Georges Bank Data Management Office. (http://globec.whoi.edu/globec-dir/contact_dmo.html)');

%COMMENTS
Comments1 = sprintf('%s\n', ...
'                              Seward Johnson CTD Cast Data  ',...
'   ',...
'                   Parameter         Description                     Units',...
'                 ----------------------------------------------------------',...
'   ',...
'                   pressure                                          dbar',...
'                   temperature                                       C',...
'                   salinity                                          psu',...
'                   sigma_t                                           kg/m^3',...
'                   fluorometer                                       volts',...
'  ',...
' Instrument : NBIS Mark III / Seabrid SBE-25',...
'  ',...
' The seabird CTD was added to the Seward Johnson CTD package after cast 111 due to poor',...
' quality conductivity data. Seabird casts 112-114, 116, 124-128, 130-136, 138-140, 142-151,',...
' 153-160, 162, 164-172, and 174-185 are available in this data set.',...
'  ',...
' Calibrated CTD files provided by R. Limeburner. ',...
' Prepared by: Russ Burgett (burgett@micmac.gso.uri.edu)');

Comments4 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Apr. 26, 1995 (1995.31813697) ', ...
'         Ending_Date:    Jun. 15, 1995 (1995.45731726)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 67.78 W ', ...
'              East Bounding Coordinate: 67.13 W ', ...
'              South Bounding Coordinate: 40.52 N ', ...
'              North Bounding Coordinate: 41.41 N ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               Dave Hebert', ...
'               Graduate School of Oceanography',...
'               Univ. of Rhode Island',...
'               Narragansett, RI 02882-1197',...
'               USA ', ...
'               Electronic Mail Address:INTERNET > hebert@micmac.gso.uri.edu',...
'               FAX: 401-874-6728',...
'         Address - globec: ',...
'               Robert Groman',...
'               Swift House MS# 38',...
'               Woods Hole, MA 02543-1127',...
'               USA ',...
'               Electronic Mail Address:INTERNET > rgroman@whoi.edu',...
'               FAX: (508) 457-2169',...
'         Address - dods: ',...
'               Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments4];


% $Log: gbsjctd.m,v $
% Revision 1.1  2002/04/15 20:04:58  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.4  2000/12/27 21:03:45  kwoklin
% Fix getfunction, getcat and geturl function names.   klee
%
% Revision 1.3  2000/12/21 16:40:16  kwoklin
% Add Catvars, Catselc, Catstr and uncommand Time/Lon/Lat names for
% compatibility with loaddods w/o -A option.  If the option is used,
% Catxxx should be commanded out.                              klee
%
% Revision 1.2  2000/12/05 18:06:35  kwoklin
% Remove flvolt from SelectableVarible as it appeared missing in one obj. klee
%
% Revision 1.1  2000/09/19 20:50:41  kwoklin
% First toolbox internal release.   klee
