function [argout1, argout2, argout3, argout4, argout5, argout6, ...
      argout7, argout8] = getjgsta(mode, get_ranges, get_dset, ...
    get_vars, get_dset_stride, get_num_urls, get_georange, ...
    get_variables, get_archive, whichurl, URLinfo)

%
% 
% GETJGSTA: a DODS browse getfunction for JGOFS datasets.
%
% This function is used to get hydrography type of data with depth, 
% time and location information displayed. 

% The preceding empty line is important

% $Id: getjgsta.m,v 1.1 2002/04/15 20:04:58 dan Exp $
% klee

global urlinfolist tmp_times xdims ydims zdims urllist old_vars old_dset ...
       old_ranges old_stride whichvariables totalsizes

% initialize return arguments
argout1 = [];
argout2 = [];
argout3 = [];
argout4 = [];
argout5 = [];
argout6 = [];
argout7 = [];
argout8 = [];

if exist(get_archive) == 2
  eval(get_archive)
else
  dodsmsg(['Problem reading dataset metadata ' get_archive '.m'])
  return
end

if nargin == 0
  dodsmsg('getgjsta requires at least a mode argument')
  return
end

if strcmp(mode,'cat') 		
  
  % --------------------  IN CAT MODE -----------------------------
  
  % SET UP THE METADATA
  % ***************************************************************
  % Create  constraint expression form browser input values-
  % date, lat/lon, archive type and depth
  % ***************************************************************
  
  %catch any unmatched data range
  if(get_ranges(4,1) > TimeRange(2) | get_ranges(4,2) < TimeRange(1))
    dodsmsg(' Requested time range does not overlap data. Please respecify')
    return
  end
  
  %save these values
  old_ranges = get_ranges;
  old_dset = get_dset;
  old_vars = get_vars;
  old_stride = get_dset_stride;
  totalsizes = [];
  
  %fill up returned arguments with dummy values to prevent crashes
  num_url = 1;  %set default
  loaddodsbool = 1; %set default 
  tmp_times = []; depths = []; lats = []; lons = []; 
  url = [];  urlinfolist = [];
  
  if exist('Cat_m_File') == 1 % check if 'Cat_m_File' is a local variable
    if exist(Cat_m_File) == 2 % check if Cat_m_File is a script
      eval(['[url,loaddodsbool,urlinfolist,tmp_times,',...
	    'zdims,ydims,xdims,num_url] = ', ...
	    Cat_m_File, ...
	    '(get_archive, get_ranges, mode, get_variables);'])
      argout6 = url;
    else
      dodsmsg(['Unable to find script ' Cat_m_File])
      return
    end
  end

  % get the inventory explicitly (loaddodsbool == 1)
  % note that normally there's only one loaddods call for jgofs/ff
  %     servers; if more than one call is necessary, let 'getcat'
  %     function or 'geturl' function to handle it.
  dods_err = 0;
  if loaddodsbool == 1
    if ~isempty(findstr(url, 'nph-jg'))
      % be sure to use '-F' tag cause jgofs returns string vector
      loaddods('-e -F',url);
    else
      % added condition here -- dbyrne 99/10/28
      if ~isempty(url)
	loaddods('-e', url);
      end
    end
    if dods_err == 1
      % PCC added the following to soften the blow on 2/4/02
      % Guessing that the following message means that server failed, not answering.
      imtch = findstr( dods_err_msg, 'Error: Fatal Error: operation failed (0)'); 
      if ~isempty(imtch)
        imtch = findstr( URL, '?');
        if isempty(imtch)
          imtch = length(URL) + 1;
        end
        base_URL = URL(1:imtch-1);
        dds_URL = strcat( base_URL, '.dds');
        dods_err_msg = sprintf('%s\n\n%s\n%s\n%s\n\n\%s', ...
          '           >>>>>>>> ERROR IN DODS DATA ACQUISITION <<<<<<<<', ...
          dods_err_msg, ...
          '  It is likely that the server is not responding. You might try', ...
          '  the following URL in your browser to see if it is alive:', ...
           dds_URL);
      else
        dods_err_msg = sprintf('%s\n%s', ...
          '           >>>>>>>> ERROR IN DODS DATA ACQUISITION <<<<<<<<', ...
          dods_err_msg);
      end
      % End PCC additions/modifications
      return
    end
  end
  
  %%%%%%%%%%%%%%%%%%%%%%%%
  % WHICH VARIABLES ARE SELECTED?
  % NOTE: get_variables is the selectablevariables
  whichvariables = [];
  for i = 1:size(get_variables,1)
    for j = 1:size(SelectableVariables,1)
      if strcmp(deblank(get_variables(i,:)), ...
	    deblank(SelectableVariables(j,:)))
	whichvariables = [whichvariables j];
      end
    end
  end
  %%%%%%%%%%%%%%%%%%%%%%%%%
  
  if num_url > 0
    eval(['[urllist,urlinfolist]=', URL_m_File, '(get_archive,' ...
	  'get_ranges,''get'',whichvariables,urlinfolist);'])
  else
    return
  end
  
  % return x/y/z/time name here
  varnames = urlinfolist(1).var_name;
  LatitudeName = deblank(varnames(1,:));
  LongitudeName = deblank(varnames(2,:));
  DepthName = deblank(varnames(3:7,:));
  TimeName = deblank(varnames(8:17,:));
  
  % Check for Longitude convention used in the browser, need to
  % convert lon < 0 to lon+360 when master_georange(1) == 0
  if num_url < 1
    return
  end
  
  TempLongitude = [];   namebool = 0;
  if ~isempty(deblank(LongitudeName)) & exist(deblank(LongitudeName)) == 1
    TempLongitude = eval(LongitudeName);  namebool = 1;
  elseif ~isempty(xdims)
    TempLongitude = xdims;
  end
  if ~isempty(TempLongitude)
    if abs(get_ranges(1,1) - get_ranges(1,2)) >= 360
      % the data were not split into 2 fetch args!
      % don't fiddle with them
    else
      if get_georange(1) == -180
	TempLongitude = (TempLongitude >=180).*(TempLongitude-360)+ ...
	    (TempLongitude < -180).*(TempLongitude+360)+ ...
	    (TempLongitude >= -180 & TempLongitude < 180).*TempLongitude;
      elseif get_georange(1) == 0
	TempLongitude = (TempLongitude >= 360).*(TempLongitude-360)+ ...
	    (TempLongitude < 0).*(TempLongitude+360)+ ...
	    (TempLongitude >= 0 & TempLongitude < 360).*TempLongitude;
      end
      if namebool == 1
	eval([LongitudeName '= TempLongitude; clear TempLongitude'])
      else
	xdims = TempLongitude; clear TempLongitude;
      end
    end
  end % end of if ~isempty(TempLongitude)
  
  % FIXED so that if there are routines with names in TimeName, they
  % are not accidentally evaluated -- dbyrne 99/06/01
  %argout1, 2, 3, 4, 5, 6 are x, y, z, t, n, URL, respectively
  if loaddodsbool
    if isempty(tmp_times)
      if ~isempty(TimeName)
	if exist(TimeName)==1 
	  argout4 = eval(deblank(TimeName));  
	end
      end
    elseif ~isempty(tmp_times), 
      argout4 = tmp_times; 
    end
    if isempty(zdims)
      if ~isempty(DepthName)
	if exist(DepthName)==1
	  argout3 = eval(deblank(DepthName)); 
	end
      end
    elseif ~isempty(zdims), 
      argout3 = zdims; 
    end
    if isempty(ydims)
      if ~isempty(LatitudeName)
	if exist(LatitudeName)==1 
	  argout2 = eval(deblank(LatitudeName)); 
	end
      end
    elseif ~isempty(ydims), 
      argout2 = ydims; 
    end
    if isempty(xdims)
      if ~isempty(LongitudeName)
	if exist(LongitudeName)==1
	  argout2 = eval(deblank(LongitudeName));  
	end
      end
    elseif ~isempty(xdims), 
      argout1 = xdims; 
    end
  else
    if ~isempty(xdims), argout1 = xdims;  end
    if ~isempty(ydims), argout2 = ydims;  end
    if ~isempty(zdims), argout3 = zdims;  end
    if ~isempty(tmp_times),  argout4 = tmp_times;  end
  end
  
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %12/28/2000
  % for jgofs inventory optimization   
  % 1 to 4 is x/y/z/t;   
  %   for example, 
  %     if argout8 == [0 0 0 4],  depth needs to be a straight line
  %     if argout8 == [1 0 0 4],  depth and time need to be straight lines
  if any(urlinfolist(1).inven_info)
    if urlinfolist(1).inven_info(1)
      argout1 = [min(argout1); max(argout1)];
    end
    if urlinfolist(1).inven_info(2)
      argout2 = [min(argout2); max(argout2)];
    end
    if urlinfolist(1).inven_info(3)
      argout3 = [min(argout3); max(argout3)];
    end
    if urlinfolist(1).inven_info(4)
      argout4 = [min(argout4);max(argout4)];
    end
  end
  %argout8 = urlinfolist(1).inven_info;
  
  if isfield(urlinfolist, 'infotext')
    if ~isempty(urlinfolist(2).infotext)
      dodsmsg(urlinfolist(2).infotext);
    end
  end
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
  % indicate if there really is any data 
  if any(length(argout1) > 0 | length(argout2) > 0 | ...
	length(argout3) > 0 | length(argout4) > 0)
    if any(all(~isnan(argout1)) | all(~isnan(argout2)) | ...
	  all(~isnan(argout3)) | all(~isnan(argout4)))
      % jg server returns a big negative number if any data is null
      argout5 = num_url;
    else
      argout5 = 0;
    end
  else
    argout5 = 0;
  end
  argout7 = urllist;
  
  % OPTIONAL: PASS OUT URLINFO SO THAT SERVER NEED NOT BE
  % ACCESSED TIME AND TIME AGAIN.
  %argout8 = urlinfolist;
  
  return
  
elseif strcmp(mode,'datasize')         
  
  %   -------------------  IN DATASIZE MODE -------------------                   
  % test conditions to see if user request has changed
  % since last catalog request
  getcat = 0;
  if isempty(old_vars) | isempty(old_dset) | isempty(old_ranges)
    getcat = 1;
  else
    if ~all(size(get_vars) == size(old_vars))
      getcat = 1;
    elseif (get_dset ~= old_dset)
      getcat = 1;
    elseif any(any(get_ranges ~= old_ranges))
      getcat = 1;
    elseif any(~isnan([old_stride get_dset_stride])) & ...
	  (old_stride ~= get_dset_stride)
      getcat = 1;
    elseif all(size(get_vars) == size(old_vars))
      if ~all(get_vars == old_vars)
	getcat = 1;
      end
    end
  end
  
  % new catalog if needed
  if getcat
    % don't need to explicitly get urllist because it's global
    [x,y,z,t,n] = getjgsta('cat', get_ranges, get_dset, get_vars, ...
	get_dset_stride, get_num_urls, get_georange, get_variables, ...
	get_archive);
    get_num_urls = n;
  end
  argout2 = get_num_urls;
  % it is only a very rough appoximation
  maxarg = max([length(tmp_times),length(xdims),length(ydims),length(zdims)]);
  argout1 = maxarg * (4 + size(get_vars,1)) * 8 / 1e6;
  
  return
  
elseif strcmp(mode,'get')    
  
  % -------------------- IN GET_DATA MODE ---------------------------
  
  if get_num_urls < 1
    dodsmsg('No data to get!') 
    return
  end
  
  % get x/y/z/time name here
  varnames = urlinfolist(1).var_name;
  LatitudeName = deblank(varnames(2,:));
  LongitudeName = deblank(varnames(1,:));
  DepthName = deblank(varnames(3:7,:));
  TimeName = deblank(varnames(8:17,:));
  
  
  %%%%%%%%%%%%%%%%%%%%%%%%
  % EVALUATE this URL
  tmpurl = [];   dods_err = 0;
  sizeofurl = 1;  indexofurl = [];
  if isfield(urlinfolist, 'sizeindex_info')
    sizeofurl = urlinfolist(1).sizeindex_info(whichurl);
    indexofurl = [urlinfolist(2).sizeindex_info(whichurl,1), ...
	  urlinfolist(2).sizeindex_info(whichurl,2)];
  end    
  if ~isempty(urllist)
    tmpurl = deblank(urllist(whichurl,:));
    if ~isempty(findstr(tmpurl, 'nph-jg'))
      loaddods('-F -e', tmpurl)
    else
      loaddods('-e', tmpurl)
    end
    if dods_err
      % PCC added the following to soften the blow on 2/4/02
      % Guessing that the following message means that server failed, not answering.
      imtch = findstr( dods_err_msg, 'Error: Fatal Error: operation failed (0)'); 
      if ~isempty(imtch)
        imtch = findstr( URL, '?');
        if isempty(imtch)
          imtch = length(URL) + 1;
        end
        base_URL = URL(1:imtch-1);
        dds_URL = strcat( base_URL, '.dds');
        dods_err_msg = sprintf('%s\n\n%s\n%s\n%s\n\n\%s', ...
          '           >>>>>>>> ERROR IN DODS DATA ACQUISITION <<<<<<<<', ...
          dods_err_msg, ...
          '  It is likely that the server is not responding. You might try', ...
          '  the following URL in your browser to see if it is alive:', ...
           dds_URL);
      else
        dods_err_msg = sprintf('%s\n%s', ...
          '           >>>>>>>> ERROR IN DODS DATA ACQUISITION <<<<<<<<', ...
          dods_err_msg);
      end
      % End PCC additions/modifications

      argout1 = '';
      argout2 = dods_err;
      argout3 = dods_err_msg;
      return
    else
      if whichurl == 1 & isfield(urlinfolist,'infotext')
	% display only during first request
	if ~isempty(urlinfolist(1).infotext)
	  dodsmsg([urlinfolist(1).infotext]);
	end
      end
    end     
  end
  %%%%%%%%%%%%%%%%%%%%%%%%
  
  %%%%%%%%%%%%%%%%%%%%%%%%
  % NOW, make up the final variablelist and whichvarlist
  tmpvarlist = [];  tmptmpvarlist = [];  tmpbasic = [];  variablelist = [];
  keep = [];  keep1 = [];  keep2 = [];  tmpkeep = [];
  issequence = urlinfolist(1).issequence;
  tmpbasic = strvcat(TimeName, 'DODS_Decimal_Date', LongitudeName, ...
      LatitudeName, DepthName);
  for i = 1:size(tmpbasic,1)
    if ~all(isspace(tmpbasic(i,:)))
      keep(i) = 1;
    end
  end
  tmpbasic = tmpbasic(find(keep),:);
  % for all the others .... includeing optional variables
  tmpvarlist = [urlinfolist(2).returned_var];
  % Assuming that if tmpvarlist is a string matrix, it implies that
  %     there're multiple servers correspond to rows of the matrix
  if size(tmpvarlist,1) > 1
    tmpvarlist = tmpvarlist(whichurl,:);
  end
  keep1 = findstr(tmpvarlist, ',');  
  keep2 = findstr(tmpvarlist, '[');
  j = 1;
  if ~isempty(keep1)
    for i = 1:length(keep1)
      if ~isempty(keep2)
	% it could be a[],b[]/a,b[]/a,b[][]/a[][],b[][],c[]/a[],b  ....
	% find commas first, then work its way back to the variable
	tmpkeep = keep2(min(find(keep2 > j)));
	if ~any(keep1(i) > tmpkeep)
	  tmptmpvarlist = strvcat(tmptmpvarlist,tmpvarlist(j:keep1(i)-1));
	else
	  tmptmpvarlist = strvcat(tmptmpvarlist,tmpvarlist(j:tmpkeep-1));
	end  
      else
	tmptmpvarlist = strvcat(tmptmpvarlist, tmpvarlist(j:keep1(i)-1));
      end
      j = keep1(i) + 1;
    end
  end
  if ~isempty(keep2) 
    tmpkeep = [];
    tmpkeep = keep2(min(find(keep2 > j)));
    if ~isempty(tmpkeep)
      tmpvarlist = strvcat(tmptmpvarlist, tmpvarlist(j:tmpkeep-1));
    else
      tmptmpvarlist = strvcat(tmptmpvarlist, ...
	  tmpvarlist(j:length(tmpvarlist)));
    end
  else
    tmpvarlist = strvcat(tmptmpvarlist, tmpvarlist(j:length(tmpvarlist)));
  end
  % combine both tmpbasic and tmpvarlist into variablelist
  variablelist = strvcat(tmpbasic, tmpvarlist);   
  
  % for whichvariablelist
  %     first, the basic 4s
  tmpwhichbasicvar = [];  tmpwhichvar = [];  tmpwhichopvar = [];  
  whichvarlist = [];
  defaultholder = strvcat('TimeName','LongitudeName','LatitudeName',...
      'DepthName');
  for i = 1:4
    tmpvnames = eval(deblank(defaultholder(i,:)));
    for j = 1:size(tmpvnames,1)
      if ~isempty(deblank(tmpvnames(j,:)))
	tmpwhichbasicvar = [tmpwhichbasicvar, i];
      end
    end
    % add the Dods_Decimal_Date
    if i == 1,  tmpwhichbasicvar = [tmpwhichbasicvar, i];  end
  end
  %     second, the selected vars
  %         before anything else, treat umbrella variable a special case
  if strcmp(deblank(DodsName),'Umbrella') == 1
    DodsName = UmbrellaDods;
    SelectableVariables = UmbrellaVariables;
  end
  for i = 1:size(tmpvarlist,1)
    for j = 1:size(DodsName,1)
      if strcmp(deblank(tmpvarlist(i,:)), deblank(DodsName(j,:)))
	tmpwhichvar = [tmpwhichvar, j];
      end
    end
  end
  %     third, the optionals
  tag = whichvariables(length(whichvariables));
  tagatsize = length(whichvariables);
  if exist('OptionalVariables') == 1 & ~isnan(OptionalVariables)          
    for i = 1:size(OptionalVariables,1)
      if exist(deblank(OptionalVariables(i,:))) == 1
	% indicate it has been returned to this workspace in loaddods call
	tmpwhichopvar = [tmpwhichopvar i];
      end
    end
  end     
  %     final, combine tmpwhichbasicvar and tmpwhichvar into whichvarlist
  whichvarlist = [tmpwhichbasicvar, tmpwhichvar+4, ...
	tmpwhichopvar+size(DodsName,1)+4];
  %%%%%%%%%%%%%%%%%%%%%%%%
  
  
  %%%%%%%%%%%%%%%%%%%%%%%%
  % GEO CONVERSION
  % Check for Longitude convention used in browser, need to convert lon < 0
  % to lon+360 when get_georange(1) == 0
  % Adopted from old version of getrectg, here multiple lonname is allowed. 
  TempLongitude = [];
  if ~isempty(LongitudeName)
    if ~isempty(deblank(LongitudeName(1,:)))
      if exist(deblank(LongitudeName(1,:))) == 1
	lonsize = 0;
	lonsize = size(LongitudeName,1);
	str1 = sprintf('%s%s%s','(TempLongitude >=180).*(TempLongitude-360)+',...
	    '(TempLongitude < -180).*(TempLongitude+360)+', ...
	    '(TempLongitude >= -180 & TempLongitude < 180).*TempLongitude');
	str2 = sprintf('%s%s%s','(TempLongitude >= 360).*(TempLongitude-360)+', ...
	    '(TempLongitude < 0).*(TempLongitude+360)+', ...
	    '(TempLongitude >= 0 & TempLongitude < 360).*TempLongitude');
	if lonsize == 1
	  TempLongitude = eval(deblank(LongitudeName));
	  if abs(get_ranges(1,1) - get_ranges(1,2)) < 360
	    if get_georange(1) == 0
	      eval(['TempLongitude =', str1, ';'])
	    elseif get_georange(1) == 0
	      eval(['TempLongitude =', str2, ';'])
	    end
	  end  
	  eval([LongitudeName '= TempLongitude; clear TempLongitude'])
	elseif lonsize > 1
	  for i = 1:lonsize
	    TempLongitude = eval(deblank(LongitudeName(i,:)));
	    if abs(get_ranges(1,1) - get_ranges(1,2)) < 360
	      if get_georange(1) == -180
		eval(['TempLongitude =', str1, ';'])
	      elseif get_georange(1) == 0
		eval(['TempLongitude =', str2, ';'])
	      end
	    end
	    eval([LongitudeName(i,:) '= TempLongitude; clear TempLongitude;'])
	  end  % end of for loop
      end  % end of if lonsize == 1, elseif lonsize > 1
      end  % end of exist
    end  % end of ~isempty
  end % end of ~isempty(LongitudeName)
  %%%%%%%%%%%%%%%%%%%%%%%%
  
  
  %%%%%%%%%%%%%%%%%%%%%%%%
  % Check if the basic 4s are in the return.
  %     If time is not in the workspace, leave as it is since 
  %         Dods_Decimal_Date is assigned as default.   If for 
  %         xdim/ydim/zdim, eval them to default values.
  % First, if values have been changed by the Info_Files.
  %    to eval InfoFile one more time, in case values need to be reassessed
  newlons = [];  newlats = [];  newdepths = [];  newtimes = [];
  newtmpvars = [];
  if size(urlinfolist,2) > 3 & ~isempty(urlinfolist(3).var_info)
    if urlinfolist(3).var_info
      if find(whichvarlist == 1)
	t = find(whichvarlist == 1);
	for m = 1:length(t)-1
	  eval(['newtimes.t',num2str(m),' = ' ...
		'eval(deblank(variablelist(t(m),:)));'])
	end
      end
      if find(whichvarlist == 2)
	newlons = eval(deblank(variablelist(find(whichvarlist == 2),:)));
      end
      if find(whichvarlist == 3)
	newlats = eval(deblank(variablelist(find(whichvarlist == 3),:)));
      end
      if find(whichvarlist == 4)
	newdepths = eval(deblank(variablelist(find(whichvarlist == 4),:)));
      end
      newtmpvars = [];
      t = find(whichvarlist > 4);
      for m = 1:length(t)
	eval(['newtmpvars.t',num2str(m),' = ' ...
	      'eval(deblank(variablelist(t(m),:)));'])
      end
    end
  end
  if exist('GeoInfo_File') == 1
    if exist(GeoInfo_File) == 2
      eval(['[geostr,servers,newlats,newlons,urlinfolist] = ',GeoInfo_File,...
	    '(''value'',get_archive,get_ranges,mode,get_vars,urlinfolist,' ...
	    'newlons,newlats,newdepths,newtimes,newtmpvars);']);
    end
  end
  if exist('DepthInfo_File') == 1
    if exist(DepthInfo_File) == 2
      eval(['[depthstr,servers,newdepths,urlinfolist] = ',DepthInfo_File,...
	    '(''value'',get_archive,get_ranges,mode,get_vars,urlinfolist,' ...
	    'newlons,newlats,newdepths,newtimes,newtmpvars);']);
    end
  end
  if exist('TimeInfo_File') == 1
    if exist(TimeInfo_File) == 2
      eval(['[timestr,servers,newtimes,urlinfolist] = ',TimeInfo_File,...
	    '(''value'',get_archive,get_ranges,mode,get_vars,urlinfolist,', ...
	    'newlons,newlats,newdepths,newtimes,newtmpvars);']);
    end
  end
  if ~isempty(urlinfolist(7).zdim_info)
    zdims = urlinfolist(7).zdim_info;
  elseif ~isempty(newdepths)
    zdims = newdepths;
  end
  if ~isempty(urlinfolist(3).xdim_info)
    xdims = urlinfolist(3).xdim_info;
  elseif ~isempty(newlons)
    xdims = newlons;
  end
  if ~isempty(urlinfolist(3).ydim_info)
    ydims = urlinfolist(3).ydim_info;
  elseif ~isempty(newlats)
    ydims = newlats;
  end
  if ~isempty(urlinfolist(5).time_info)
    tmp_times = urlinfolist(5).time_info;
  elseif ~isempty(newtimes)
    tmp_times = newtimes;
  end
  if urlinfolist(3).var_info
    tmpvar = [];
    for m = 1:length(t)
      if isfield(urlinfolist, 'newvars')
	tmpvar = deblank(eval(['variablelist(',num2str(t(m)),',:)']));
	eval([tmpvar ' = urlinfolist(m).newvars; '])
      end
    end
  end
  clear newtimes newlats newlons newdepth
  
  for i = 1:size(defaultholder,1)
    tmpvars = eval(deblank(defaultholder(i,:)));
    if ~isempty(tmpvars)
      % if x/y/z is in the DodsName but somehow is not returned, use the 
      %      name in DodsName
      for j = 1:size(tmpvars,1)
	tmpvar = deblank(tmpvars(j,:));
	if ~isempty(tmpvar)
	  %%if ~isempty(eval(tmpvar)) & ~exist(tmpvar) == 1
	  if ~isempty(eval(tmpvar)) 
	    if ~exist(tmpvar) == 1 & ~urlinfolist(3).var_info
	      % var is not returned to the workspace
	      switch i
		case 3
		  eval([tmpvar, '= ' ...
			'ydims(whichurl)*ones(sizeofurl,1);']);
		case 2
		  eval([tmpvar, '= ' ...
			'xdims(whichurl)*ones(sizeofurl,1);']);
		case 4
		  eval([tmpvar, '= ' ...
			'zdims(whichurl)*ones(sizeofurl,1);']);
		case 1
		  eval([tmpvar, '= [];']);
	      end
	    elseif exist(tmpvar) == 1 & urlinfolist(3).var_info
	      % var is reevaluated, reassign values
	      switch i
		case 3
		  eval([tmpvar, ' = ydims;']);
		case 2
		  eval([tmpvar, ' = xdims;']);
		case 4
		  eval([tmpvar, ' = zdims;']);
		case 1
		  eval([tmpvar, ' = tmp_times;']);
	      end
	    end
	  end
	end
      end
    else
      % if x/y/z is an empty holder, return something in Dods default names
      switch i
	case 2
	  if ~isempty(xdims)
	    if issequence
	      DODS_Longitude = xdims(whichurl)*ones(sizeofurl,1);
	    else
	      DODS_Longitude = xdims(whichurl,:)';
	    end
	    % don't forget to add it to the variablelist and whichvarlist
	    variablelist = str2mat(variablelist, 'DODS_Longitude');
	    whichvarlist = [whichvarlist, 2];
	  end
	case 3
	  if ~isempty(ydims)
	    if issequence
	      DODS_Latitude = ydims(whichurl)*ones(sizeofurl,1);
	    else
	      DODS_Latitude = ydims(whichurl,:)';
	    end
	    variablelist = str2mat(variablelist, 'DODS_Latitude');
	    whichvarlist = [whichvarlist, 3];
	  end
	case 4
	  % it's a lazy way to incorporate varieties of z variables
	  if ~isempty(zdims)
	    if issequence
	      DODS_Zdim = zdims(whichurl)*ones(sizeofurl,1);
	    else
	      DODS_Zdim = zdims(whichurl,:)';
	    end
	    variablelist = str2mat(variablelist, 'DODS_Zdim');
	    whichvarlist = [whichvarlist, 4];
	  end
      end
    end
  end
  %%%%%%%%%%%%%%%%%%%%%%%%
  
  %%%%%%%%%%%%%%%%%%%%%%%%
  % now convert variablelist to user-friendly names
  % here's the joggling for multi time/lat/lon/depth parameters
  % and added DodsName and OptionalVariables
  %     first, for the basic 4s
  names = [];  keep = [];
  defaultnames = str2mat('Time','Longitude','Latitude','Depth');
  tmptimename = eval(defaultholder(1,:));
  for i = 1:size(tmptimename,1)
    if ~all(isspace(tmptimename(i,:)))
      keep(i) = 1;
    end
  end
  tmptimename = tmptimename(find(keep),:);
  if ~isempty(tmptimename)
    if size(tmptimename,1) == 1, names = [defaultnames(1,:)];
    else, names = [upper(tmptimename(1,1)), ...
	    tmptimename(1,2:length(deblank(tmptimename(1,:))))]; 
      for i = 2:size(tmptimename)
	names = strvcat(names, [upper(tmptimename(i,1)), ...
	      tmptimename(i,2:length(deblank(tmptimename(i,:))))]);
      end
    end
  end 
  %     add DODS_Decimal_Date as default
  names = strvcat(names, 'DODS_Decimal_Date');
  %     for x, y and z
  for i = 2:4
    tmph = eval(defaultholder(i,:));
    if ~isempty(tmph)
      if size(tmph,1) == 1, 
	names = strvcat(names, deblank(defaultnames(i,:)));
      else, for j = 1:size(tmph,1)
	  if ~all(isspace(tmph(j,:)))
	    names = str2mat(names, [upper(tmph(j,1)), ...
		  tmph(j,2:length(deblank(tmph(j,:))))]);
	  end
	end
      end
    end
  end
  %    second, for the others
  %       remember there're tmpwhichbasicvar, tmpwhichvar, tmpwhichopvar
  %       and all together there's the whichvarlist, and whichvariables
  %       is the selected var from the pull down list only
  if length(tmpwhichvar) > length(whichvariables)
    if exist('UmbrellaVariables') == 1
      names = str2mat(names, UmbrellaVariables(tmpwhichvar,:));
    else
      names = str2mat(names, DodsName(tmpwhichvar,:));
    end
  elseif length(tmpwhichvar) == length(whichvariables)
    names = strvcat(names, SelectableVariables(whichvariables,:));
  end
  if ~isempty(tmpwhichopvar)
    names = strvcat(names, SelectableOptional(tmpwhichopvar,:));
  end
  %    third, for the extra x, y and z
  tmpholder = str2mat('DODS_Longitude','DODS_Latitude','DODS_Zdim');
  for i = 1:3
    if exist(deblank(tmpholder(i,:))) == 1
      names = strvcat(names, deblank(tmpholder(i,:)));
    end
  end
  %%%%%%%%%%%%%%%%%%%%%%%%

  % check that we can write variables into names correctly
  if size(names,1) ~= size(variablelist,1)
    str = sprintf('%s\n', ...
	'Fatal Error: Discrepancy between number of names', ...
	'and size of variablelist!');
    dods_err = 1;
    dods_err_msg = str;
    argout1 = tmpurl;
    argout2 = dods_err;
    argout3 = dods_err_msg;
    return
  end
  
  %%%%%%%%%%%%%%%%%%%%%%%%
  % for starters, return the URL
  Rxx = requestnumber;
  urlname = sprintf('R%i_URL', Rxx);
  clear dods_tmpout; global dods_tmpout;
  dods_tmpout = tmpurl;
  evalin('base', 'clear dods_tmpout; global dods_tmpout')
  evalin('base', [urlname ' = dods_tmpout; clear dods_tmpout'])
  
  %%%%%%%%%%%%%%%%%%%%%%%%
  % SET UP LIST FOR ALL RETURNED_VARS
  %     now the variablelist is for all returned variables and whichvarlist
  %         is index into variablelist
  % first, for the DODS_Decimal_Date
  %     record sizes of each individual url to split 'times' off 
  %         (could use structure on times in the future)
  NullValues = [];
  totalsizes(whichurl) = sizeofurl;
  DODS_Decimal_Date = [];
  datesize = sum(totalsizes(1:whichurl));
  if isempty(urlinfolist(5).time_info)
    % if value is not reassessed
    if whichurl == 1
      DODS_Decimal_Date = tmp_times(1:datesize);
    else
      DODS_Decimal_Date = tmp_times(sum(totalsizes(1:whichurl-1))+1:datesize);
    end
  else
    DODS_Decimal_Date = tmp_times;
  end
  if whichurl == 1
    DODS_Decimal_Date = tmp_times(1:datesize);
  else
    DODS_Decimal_Date = tmp_times(sum(totalsizes(1:whichurl-1))+1:datesize);
  end
  for i = 1:size(variablelist,1)
    tmpname = deblank(variablelist(i,:));
    if ~isempty(tmpname)
      if exist(tmpname) == 1
	% make a temporary variable to work with & clear orig.
	clear dods_tmpout; global dods_tmpout
	dods_tmpout = eval(tmpname); eval(['clear ' tmpname])
	finalname = sprintf('R%i_%s', Rxx, deblank(names(i,:)));
	copycmd = sprintf('%s; %s = dods_tmpout; %s', ...
	    'global dods_tmpout', finalname, ...
	    'clear dods_tmpout');
	if ~strcmp(tmpname, 'DODS_Decimal_Date')
	  % here, reeval returned vars according to indexofurl  
	  %     some precautions have to be done if something 
	  %     wrong with the networks, so that the expected returned
	  %     size is not equal to the real returned size (in other 
	  %     words, size from cat ~= size from get because timeout, etc
	  if issequence
	    if size(dods_tmpout,1) == indexofurl(2)         
	      dods_tmpout = dods_tmpout(indexofurl(1):indexofurl(2));  
	    else
	      % leave dods_tmpout as it is
	      % DODS_Decimal_Date has to be re-evaled
	      %     assume only the first few data are returned
%	      if totalsizes(whichurl) >= sizes(i,1)
%		DODS_Decimal_Date = DODS_Decimal_Date(1:sizes(i,1));
%	      else
%		DODS_Decimal_Date = [];
%	      end
	    end
	  end
	  if exist('DataNull') == 1
	    if iscell(DataNull)
	      if any(~isnan(DataNull{whichvarlist(i)}))
		NullValues = DataNull{whichvarlist(i)};
		for k = 1:length(NullValues)
		  j = find(dods_tmpout == NullValues(k));
		  dods_tmpout(j) = NaN*j;
		end
	      end
	    else
	      if ~isnan(DataNull(whichvarlist(i)))
		j = find(dods_tmpout == DataNull(whichvarlist(i)));
		dods_tmpout(j) = NaN*j;
	      end
	    end
	  end
	  % stack data in a column and scale it if possible
	  if exist('DataScale') == 1
	    % DataScale now contains all the variables that
	    % need to be returned   klee 04/01/99
	    if ~isnan(OptionalVariables) & size(DataScale,1) ~= ...
		  size(DodsName,1)+size(OptionalVariables,1)+4
	      dodsmsg(['Error is in ' get_archive '.m'])
	    elseif isnan(OptionalVariables) & size(DataScale,1) ~= ...
		  size(DodsName,1)+4
	      dodsmsg([ 'Error in DataScale in ' get_archive '.m'])
	    else
	      if ~isnan(DataScale(whichvarlist(i),1))
		dods_tmpout =  DataScale(whichvarlist(i),1) + ...
		      dods_tmpout*DataScale(whichvarlist(i),2);
	      end
	    end
	  end
	end
	
	% copy the data to the user workspace
	evalin('base', copycmd)

      end % end of check for existence of tmpname
    end % end of ~isempty(tmpname)
  end
  %%%%%%%%%%%%%%%%%%%%%%%%
  
  argout1 = tmpurl;
  argout2 = 0;
  argout3 = '';
  return
  
end % /* end of mode check */

% $Log: getjgsta.m,v $
% Revision 1.1  2002/04/15 20:04:58  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.15  2002/04/11 16:31:35  dan
% Change times to tmp_times to avoid problem with times operator.
%
% Revision 1.14  2002/02/08 23:02:59  dan
% Added text to the dialog box that comes up on a loaddods error
% saying that it is likely that the server is down and suggesting
% how to check this.
%
% Revision 1.13  2002/01/23 17:03:00  dbyrne
%
%
% Slight fix to usage of findstr. dbyrne 2002/01/23
%
% Revision 1.12  2001/01/18 18:33:34  dbyrne
%
%
% Generalized getfunctions that return ND arrays directly to user workspace.
% -- dbyrne 01/01/18
%
% Revision 1.11  2000/12/29 00:40:00  kwoklin
% Add jgofs inventory optimization code.  klee
%
% Revision 1.10  2000/12/28 17:06:45  kwoklin
% Fix a typo in DODS_Longitude.   klee
%
% Revision 1.9  2000/12/19 15:47:07  kwoklin
% Add cell-array functionality for DataNull.   klee
%
% Revision 1.8  2000/12/19 15:39:41  kwoklin
% Flip numbers for xdim and ydim.    klee
%
% Revision 1.7  2000/12/06 19:11:47  kwoklin
% Wrap up Umbrella variable. Fix call error in gbcat.  klee
%
% Revision 1.6  2000/12/05 20:16:59  kwoklin
% Fix a typo.  klee
%
% Revision 1.5  2000/12/05 18:01:46  kwoklin
% Fix typos in epstruct, derefdat, gettstr and getjgsta.
% Fix returned argout6 to catserver in gbcat.
% Differentiate depth and heigth in getcat and getinfo.
% Add string building functionality in gburl for focus data set.  klee
%
% Revision 1.4  2000/11/14 19:21:24  kwoklin
% Minor update for usgsts and nmfscur data sets.  klee
%
% Revision 1.3  2000/11/02 16:04:20  kwoklin
% Adding data reeval after returned from get_data call (mainly for frontal
% data sets). Modify gbcat and gburl accordingly (more ad hoc implementations).
% klee
%
