%  
%         Total Daily Solar Radiation for Newport, Rhode Island

% $Id: gsoepd.m,v 1.1 2002/04/15 20:04:58 dan Exp $
% klee          12/11/2000
% Ruth Platner  03/01/2000

Server = 'http://aspre.gso.uri.edu/cgi-bin/dods/nph-jg/eppleydaily';
GetFunctionName = 'getjgsta';
Cat_m_File = 'gbcat';
URL_m_File = 'gbburl';

LonRange = [-71.3125 -71.3125];
LatRange = [41.5 41.5];
TimeRange = [1995.5809341669 1998.9150665998];
DepthRange = [-15 -15];
Resolution = nan;

DataName = 'MET - Total Daily Solar Radiation for Newport, Rhode Island - URI';
TimeName = str2mat('YYYY','MM','DD','DecimalDate');
LongitudeName = 'lon';
LatitudeName = 'lat';
DepthName = str2mat('','','height','','');
DepthUnits = 'Meters';
DepthFlag = [0;0;1;0;0];

DodsName = str2mat('CumSI_Unit');
SelectableVariables = str2mat('Eppley_PSP_Cum');
OptionalVariables = str2mat('YYYY','MM','DD');
SelectableOptional = str2mat('Year','Month','Day');

DataNull = [NaN NaN NaN NaN -999.9 nan nan nan];

Acknowledge = sprintf('%s\n\n%s\n%s\n%s', ...
    [ 'The data were provided by the University of Rhode Island ', ...
      '(http://aspre.gso.uri.edu/dods/eppley/eppley.html)',...
      'and accessed via the Distributed Oceanographic Data System ',...
      '(DODS: http://www.unidata.ucar.edu/packages/dods).']);
Data_Use_Policy = [];

Comments1 = sprintf('%s\n','',...
 '                     Total Daily Solar Radiation',...
 '      ',...
'Parameter         Description                         Units',...
'--------------------------------------------------------------------------',...
'YYYY              Calendar Year                       4 digit integer',...
'MM                Calendar Month                      2 digit integer',...
'DD                Day of Month                        2 digit integer',...
'DecimalDate       This is a double                    years ',...
'             precision, numeric date equal to the number of days since ',...
'             January 1.  i.e.,1995.0000000 = 1995/01/01/00/00. ',...
'             DecimalDates have been calculated for a time at the end of ',...
'             each hour.',...
'lat               Location of Instrument in Latitude  degrees east',... 
'lon               Location of Instrument in Longitude degress north',...
'height            Location of Instrument              meters',...
'             in Height above sea level   (15 meters above sea level, ',...
'                  this is 10 meters above ground) ',...
'CumSI_Unit        Cumulative Integrated Hourly        watt-hour/m2',...
'             Irradiance in SI Units',...
		    '    ',....
'             A laboratory in Newport, Rhode Island maintains a sensor on ',...
'their roof which integrates the total irradiance received each hour. The ',...
'sensor is an Eppley Precision Spectral Pyranometer (PSP). The PSP is a ',...
'World Meteorological Organization Secondary Standard Radiometer designed ',...
'for the measurement of sun and sky radiation. ',...
		    '       ',...
'The data served here by DODS are available from August, 1995 to November,',...
'1998. Hard copies of Excel spreadsheets for this same time period are ',...
'available in the Pell Library on the URI/GSO campus. Also at the Pell ',...
'Library are other hard copy data from this sensor since 1972. These will ',...
'be available online in the future. ',...
		    '        ',...
'The data represent total solar radiation; i.e., total incident irradiance,',...
'and not photosynthetically active radiation (PAR). The Newport ',...
'laboratory''s PSP produces a millivolts signal that is directly proportion',...
'-al to the sun''s irradiance. By dividing the output by the instrument''s',...
'sensitivity one can determine the irradiance. ',...
		    '      ',...
'As of April 1997, data are reported in Eastern Standard Time (not Daylight',...
'Savings Time).   Prior to that, data were recorded in EST or DST depending',...
'on the time of year.  The hard copy data in Pell Library should contain',...
'the label "EST" or "DST" on the day the switch occurred.  This on-line ',...
'dataset that is served by DODS uses Eastern Standard Time only. Where ',...
'hard copy data was reported in Daylight Savings Time, the on-line data ',...
'have been converted to EST. ');

Comments2 = sprintf('%s\n','',...
		    '    ',...
		    '    ',...
'Data Processing and Conversions',...
		    '    ',... 
'The data are received directly from the laboratory as cumulative ',...
'integrated hourly irradiance.   The cumulative data are subtracted over ',...
'each hour to compute the irradiance received during each hour.  This ',...
'calculation is intentionally not carried out for the night hours, because',...
' the sensor occasionally detects a flash of light or a street lamp which ',...
'is not meaningful in terms of the open water. ',...
		    '    ',...
'Prior to April 1997, the laboratory reported the cumulative data as ',...
'langleys (g cal/cm2).  In April 1997, the laboratory switched to the SI ',...
'Unit, watts-hour/m2. Internationally, solar radiation is expressed in ',...
'terms of the Systems Internationales des Unites (SI Units) of ',...
'watts-hr/meter2. ',...
		    '    ',...
'This on-line dataset includes the cumulative and hourly data as SI Unit.',...
'For data prior to April 1997, the cumulative Langleys have been converted',...
'to SI Unit. ',...
		    '    ',...
'           The conversion from watt-hour/m2 to langleys is ',...
		    '    ',...
'            1 cal/cm2/min = 697.3 watts/m2, so ',...
'            1 langley = 697.3/60 = 11.622 Watt-hour/m2 ',...
		    '   ',...
'                                or ',...
		    '   ',...
'            1 watt/m2 = 0.086046178 langleys',...
		    '   ',...
		    '    ',...
'Missing Data and Corrections',...
		    '   ',...
'  Missing Data ',...
'    The data for April 1-9, 1997 are missing.  During this period, the ',...
'laboratory was reconditioning their light meter (and changing to SI units).',...
		    '   ',...
'  An Incorrect Multiplier ',...
'    During this period they noticed that from June 13, 1991 to March 31, ',...
'1997, the light meter was incorrectlycalibrated.  An incorrect multiplier ',...
'was used.  For the online dataset described here and Excel spreadsheet',...
'data prior to April 1997, this correction has been made by multiplying ',...
'by 5.91/7.61. ',...
		    '   ',...
'  Light Meter not Re-calibrated ',...
'    The laboratory has also communicated to us that their light meter was',...
' not re-calibrated from 1985 - 1997, so there would have been a drop in ',...
'instrument sensitivity over this time period.  This has not been accounted',...
'for in the Excel spreadsheets or in other hard copy data, but the hourly ',...
'and cumulative online dataset described here has been corrected.  The ',...
'laboratory has suggested two ways to correct the data which follow. The ',...
'dataset described here has received correction number 1. ',...
		    '   ',....
'      (1) There would have been a 12% drop in sensitivity from 1985-1997,',...
'so one could increase the data by 1% per year over this time period.  ',...
'The dataset described here has received this correction. Values each day ',...
'starting on April 1, 1985 (12 years prior - the exact day to start ',...
'correcting is uncertain) should be increased by: ',...
		    '    ',....
'  12% / [(9 yrs x 365 days) + (3 yrs x 366 days)] = 0.002738 % each day ',...
		    '   ',...
'                                 or ',...
		    '    ',....
'    increase the value on March 31, 1997 by 12%, ',...
'   then increase the value on March 30 by 12-0.002738 %, ',...
'  increase the value on March 29 by 12-0.005476 %, and so on.',...
		    '   ',...
		    '    ',...
'      (2)  The data for 1985 and 1986 are probably okay, so one can begin ',...
'applying corrections in 1987.  This scenario would call for a 1.1% per ',...
'year correction to the data from Jan 1987 through the recalibration in ',...
'1997. ',...
		    '    ',...
		    '    ',...
'     Regarding which correction to use, the laboratory wrote: ',...
		    '    ',....
'     "It''s entirely up to you as there is no set standard.  Please be ',...
'advised that no matter what correction method you use, this data is only ',...
'going to be accurate to a certain percentage.  What that percentage will ',...
'be is difficult (if not impossible) to determine but I would guess 5% or ',...
'so after the correction." ',...
		    '    ',...
'                      Table of Corrections to data',...
		    '   ',...
'data type   Multiplier (5.91/7.61)            12% Correction',...
'CumSI_Unit  June 13, 1991 to March 31, 1997   April 1, 1985 to March 31, 1997',...
		    '    ',...
		    '    ',...
'Data Quality',...
		    '   ',...
'Users of this data set should be aware that no quality assurance methods ',...
'were employed by the original supplier of the data. People at URI ',...
'responsible for this dataset have replaced some data with missing value ',...
'flags when there were obvious problems with the data. ');

Comments3 = sprintf('%s\n',...
        '   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Aug. 01, 1995 (1995.5809341669)', ...
'         Ending_Date:    Nov. 30, 1998 (1998.9150665998)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 71.3125 W ', ...
'              East Bounding Coordinate: 71.3125 W ', ...
'              South Bounding Coordinate: 41.5 N ', ...
'              North Bounding Coordinate: 41.5 N ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - data interpretation: ', ...
'               Director, Pell Marine Science Library ', ...
'               Graduate School of Oceanography',...
'               University of Rhode Island',...
'               South Ferry Road',...
'               Narragansett, RI 02882-1197',...
'               USA ', ...
'               Electronic Mail Address:INTERNET > pellib@gso.uri.edu',...
'         Address - dods: ',...
'               Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');
Comments = [Comments1 Comments2 Comments3];


% $Log: gsoepd.m,v $
% Revision 1.1  2002/04/15 20:04:58  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.2  2000/12/21 16:40:16  kwoklin
% Add Catvars, Catselc, Catstr and uncommand Time/Lon/Lat names for
% compatibility with loaddods w/o -A option.  If the option is used,
% Catxxx should be commanded out.                              klee
%
% Revision 1.1  2000/12/19 15:42:11  kwoklin
% First toolbox internal release.  klee
%
