%
%      URI 1.2km Hatteras to Nova Scotia SST fronts
 
%
% $Id: htnfront.m,v 1.1 2002/04/15 20:08:26 dan Exp $
% klee 11/2000
% klee 12/1998

GetFunctionName = 'getjgsta';
Cat_m_File = 'gbcat';
URL_m_File = 'gburl';
Server = 'http://dods.gso.uri.edu/cgi-bin/nph-jg/htnfronts';

LonRange = [-77.53 -63.05];
LatRange = [34.65 45.75];
TimeRange = [1985.0 1996.0];
DepthRange = [0 0];
DepthUnits = '';
Resolution = 1.236;          % avg resolution

DodsName  = str2mat('sst','sstgrad','sstgraddir');
SelectableVariables = str2mat('Sea_Temp','Temp_Grad','Grad_Direction');
DataName = 'SST - Hatteras to Nova Scotia SST Fronts - URI';       
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName = 'time'; 
DepthName = '';
OptionalVariables = nan;
GeoInfo_File = 'geofront';

Acknowledge = sprintf('%s\n\n%s\n%s\n%s\n%s\n%s\n%s', ...
    [ 'The authors of this dataset are J.F. Cayula, D.S. Ullman and P. Cornillon.  ', ...
      'The data were provided by the University of Rhode Island ', ...
      '(http://www.cdc.noaa.gov) and accessed via ', ...
      'the Distributed Oceanographic Data System (DODS: ', ...
      'http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citations: Cayula, J-F., P. Cornillon, R. Holyer and S. Peckinpaugh. ',...
      'Comparative Study of Two Recent Edge Detection Algorithms Designed ',...
      'to Process Sea Surface Temperature Fields. ',...
      'IEEE Trans. on Geo. Rem. Sens., 29:175-177, 1991.'],...
    [ 'Cayula, J-F. and P. Cornillon. Edge detection algorithm for SST ',...
      'images. J. Atmos. Oceanic Technol., Vol. 9, No. 1, 67-80, 1992 '], ...
    [ 'Cayula, J-F. Multi-image edge detection for SST images. J. Atmos. ',...
      'Oceanic Technol., Vol. 12, No. 4, 821-829, 1995 '], ...
    [ 'Cayula, J-F. and P. Cornillon. Cloud Detection from a Sequence of SST ',...
      'Images. Remote Sens. Environ, 55:80-88, 1996. '],...
    [ 'Ullman, D. S. and P. C. Cornillon, Surface Temperature Fronts off the ',...
      'East Coast of North America from AVHRR Imagery, J. ',...
      'Geophy. Res., submitted 1998.']);

Comments1 = sprintf('%s\n', ...
'                  URI 1.2km Hatteras to Nova Scotia SST fronts', ...
'     ', ...
'    The sea surface temperature (SST) fronts in this dataset are objectively', ...
'    located by application of an automated edge detection algorithm to SST', ...
'    images. ', ...
'    ', ...
'    The images cover the area from 34.68N to 45.72N and from 77.53W to 63.07W', ...
'    with a resolution of approximately 1.2 km/pixel, and are available for the', ...
'    period 1985 - 1996. (To view these SST images via this interface select the', ...
'     "Hatteras to Nova Scotia AVHRR" data set.)', ...
'    ', ...
'    Prior to edge detection, cloud-contaminated pixels are masked in the images', ...
'    using a declouding algorithm developed at the University of Rhode island. ', ...
'    For each SST image, this dataset provides location, SST, SST gradient and SST ', ...
'    gradient direction information for each pixel that was identified as a frontal ', ...
'    pixel.', ...
'    ', ...
'    References ', ...
'    ', ...
'    Cayula, J-F., P. Cornillon, R. Holyer and S. Peckinpaugh. Comparative Study of Two ',...
'    Recent Edge Detection Algorithms Designed to Process Sea Surface Temperature Fields. ',...
'    IEEE Trans. on Geo. Rem. Sens., 29:175-177, 1991.',...
'    ',...
'    Cayula, J-F. and P. Cornillon. Edge detection algorithm for SST images. J. Atmos. ',...
'    Oceanic Technol., Vol. 9, No. 1, 67-80, 1992 ', ...
'    ', ...
'    Cayula, J-F. Multi-image edge detection for SST images. J. Atmos. Oceanic Technol.,',...
'    Vol. 12, No. 4, 821-829, 1995 ', ...
'    ', ...
'    Cayula, J-F. and P. Cornillon. Cloud Detection from a Sequence of SST Images. Remote',...
'    Sens. Environ, 55:80-88, 1996. ',...
'    ', ...
'    Ullman, D. S. and P. C. Cornillon, Surface Temperature Fronts off the East Coast of ',...
'    North America from AVHRR Imagery, submitted to Journal of Geophysical Research, 1998.');

Comments2 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Jan. 1, 1985 ', ...
'         Ending_Date: Dec. 31, 1996 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 77.5326 W ', ...
'              East Bounding Coordinate: 63.0674 W ', ...
'              South Bounding Coordinate: 34.6758 N ', ...
'              North Bounding Coordinate: 45.7242 N ', ...
'    Units:  Once converted from digital counts ==> Degrees Centigrade ', ...
'    Spatial Resolution: 1.2 km',...
'    Thermal Resolution: .125 deg. C ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address: ', ...
'               Peter Cornillon ', ...
'               Graduate School of Oceanography ', ...
'               University of Rhode Island ', ...
'               South Ferry Road ', ...
'               Narragansett, Rhode Island  02882 ', ...
'               USA ', ...
'         Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2];
  

% $Log: htnfront.m,v $
% Revision 1.1  2002/04/15 20:08:26  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.4  2001/01/18 19:35:44  dbyrne
%
%
% datarange is no longer in use.  changed datanull to cell in many cases.
% -- dbyrne 01/01/17
%
% Revision 1.3  2000/12/21 16:40:16  kwoklin
% Add Catvars, Catselc, Catstr and uncommand Time/Lon/Lat names for
% compatibility with loaddods w/o -A option.  If the option is used,
% Catxxx should be commanded out.                              klee
%
% Revision 1.2  2000/11/02 15:59:54  kwoklin
% URI frontal data sets toolbox version.  Integrated w/ getjgsta.  klee
%
