function [decyear,yearday,year] = invjul(juliandays,str)

%
% Calcuate decimal year and/or (yearday, year) from julian day
% only after 1969.
%
% Usage:
% [decyear] = invjul(juliandays, 1)
% [yearday, year] = invjul(juliandays, 2)
% [decyear, yearday, year] = invjul(juliandays, 3)
%
% str == 1, returns decyear only
% str == 2, returns in yearday and year format
% str == 3, returns all decyear, yearday and year
%
% Note: This program assumes 1 as the first day of the year
%

% $Id: invjul.m,v 1.1 2002/04/15 20:08:42 dan Exp $
% klee 09/01/99

decyear = []; yearday = []; year = []; days = []; dayleft = [];

if ~isempty(nargin)
  if nargin == 1 
    % if no str is specified, return decyear only
    decyear = invjul(juliandays, 1);
    return
  end
else
  return;
end

% days since 1969
if juliandays > 2440000
  days = juliandays - 2440000 - 222;  
end

leapy = fix(days/1461);
dayleft = round((days/1461 - leapy) * 1461);
%if leapy > 0
%  dayleft = dayleft - 1461*leapy;
%end
count = 0;
while dayleft > 0
  if count < 3
    dayleft = dayleft - 365;
    count = count + 1;
  else 
    dayleft = dayleft - 366;
    count = count + 1;
  end
end
isleapyear = 0;
if count < 4
  if ~isempty(dayleft)
    if dayleft == 0
      dayleft = 365;
    else
      dayleft = dayleft + 365;
    end
  end
else
  isleapyear = 1;
  if ~isempty(dayleft)
    if dayleft == 0
      dayleft = 366;
    else
      dayleft = dayleft + 366;
    end
  end
end
yearday = dayleft;
year = 1969 + count + leapy*4 - 1;
if isleapyear == 1
  decyear = year + yearday / 366;
else
  decyear = year + yearday / 365;
end

if str == 1
  year = []; yearday = [];
elseif str == 2
  decyear = [];
end

return
  
  
% $Log: invjul.m,v $
% Revision 1.1  2002/04/15 20:08:42  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.1  2000/11/14 19:27:19  kwoklin
% First toolbox internal release.  Note that the TEMP/TEMPERATURE switch
% for nmfscur is disabled in the hope that the data files would be self-
% corrected in the near future.   klee
%
% Revision 1.1  1999/11/23 18:12:15  kwoklin
% R. Signell's time-series and profile data files.   klee
%
