function [URL, URLinfo] = jplczurl(archive, URLinfo, LonRange, Nlon, ...
    LatRange, Nlat, dset_stride, ranges, variable, server)
%----------------------------------------------------------------------------
%
% Formal parameters:
% archive: Name of .m file containing metadata about this dataset. 
% URLinfo: Matrix from jplczcscat.
% StartColumnumn, ...: Integers denoting the obvious stuff about the data's
% matrix. 
% dset_stride: The stride value to use when reading the data. 
% nvars: Not used.
%
% NB: URLinfo: This is a matrix of time with the year, day and
% ascending/descending flag of each hit. Note that the day here is the
% calendar day and the flag uses 0 for ascending and 1 for descending.

% The return values are:
% URL: A vector of URLs, one for each element of URLinfo.
%
% $Log: jplczurl.m,v $
% Revision 1.1  2002/04/15 20:09:04  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.2  2001/01/18 18:59:12  dbyrne
%
%
% Fixed bugs and enhanced to use URLinfo. -- dbyrne 01/01/18
%
% Revision 1.1  2000/05/31 23:12:55  dbyrne
% *** empty log message ***
%
% Revision 1.1  2000/05/31 22:59:20  root
% *** empty log message ***
%
% Revision 1.1  1999/05/13 02:55:20  dbyrne
%
%
% New palettes, dataset files with shortened names, and a few new scripts for
% release 3.0.0. -- dbyrne 99/05/12
%
% Revision 1.1  1999/05/13 01:22:24  root
% These are all files that had names shortened from something longer.
%
% Revision 1.2  1999/03/04 13:13:29  root
% All changes since AGU week.
%
% Revision 1.2  1998/12/04 23:08:23  jimg
% Fix for Matlab 4's version of str2mat which can only take 11 or fewer
% elements.
%
%----------------------------------------------------------------------------

% Note:  Inflexibly coding the url like this isn't quite proper, but in
%        the absence of a "real" catalog server - we're going to put up
%        with it for now.  The url should come from the catalog server
%        and it is, in fact, stored there - but that string is ignored.

variable = deblank(variable);
server = deblank(server);
URL = '';
directory = [ '/' ];
monthList = str2mat(str2mat('jan', 'feb', 'mar', 'apr', 'may', 'jun'), ...
      'jul', 'aug', 'sep', 'oct', 'nov', 'dec');
% we need year, last two digits of year and first three digits
% of the month to build the rest of the path to the data.
% What is the year ?
info = URLinfo.info;
if ~isempty(info)
  year = num2str(info(:,1));
  % what is the month ?
  month = info(:,2);
  monstr = monthList(month,:);
  y2kyear = year(:, 3:4);

  %figure out if wraparound is needed.
  [start_lon,end_lon] = splitrequest(LonRange, ranges(1,:));
  rows = pixcheck(ranges(2,:), LatRange, Nlat);
  rows = rows - 1;
  numurls = size(month,1);
  URL = cell(numurls,1);
    urlcon = [];
  for k = 1:numurls
    for j = 1:length(start_lon);
      columns{j} = pixcheck([start_lon(j) end_lon(j)], LonRange, ...
	  Nlon);
      columns{j} = columns{j} - 1;

      % Change the row/col  constraint information to string.
      StartRow = num2str(rows(1));
      stride = num2str(dset_stride);
      EndRow = num2str(rows(2));
      StartColumn = num2str(columns{j}(1));
      EndColumn = num2str(columns{j}(2));

      img_name = [ 'c' y2kyear(k,:) monstr(k,:) 'v.hdf' ];

      constraint = [ '?' variable ...
	    '[' StartRow ':' stride ':' EndRow ']' ...
	    '[' StartColumn ':' stride ':' EndColumn ']'];

      urlcon1 = [rows columns{j}];
      iURL = [ server directory img_name constraint ];
      if ~isempty(URL{k}), URL{k} = [URL{k} ' '];  end
      URL{k} = [URL{k} iURL];
      if k == 1
	urlcon = [urlcon; urlcon1];
      end
    end
  end
  urlcon = num2cell(urlcon,2);
  URL = char(URL);
  axindex{1} = [rows];
  axindex{2} = cat(1,columns{:});
  URLinfo.axindex = axindex(:);
  URLinfo.stride = [dset_stride; dset_stride];
  mapnames = cell(2,1);
  URLinfo.axnames = mapnames;
  URLinfo.urlconstraint = urlcon(:);
else
  URLinfo.axindex = cell(2,1);
  URLinfo.stride = [dset_stride; dset_stride];
  mapnames = cell(2,1);
  URLinfo.axnames = mapnames;
  URLinfo.urlconstraint = {};
end

return;


