function [timestr,servers,tmptimes,urlinfolist] = nfcurt(str,getarchive,...
                  getranges,getmode,getvars,urlinfolist,varargin)

%
%  Calculate time index for usgs time-series and nmfs current meter
%      data sets.
%

% The preceding empty line is important
% $Id: nfcurt.m,v 1.1 2002/04/15 20:05:57 dan Exp $
% klee

% initialization
timestr = [];  servers = []; tmptimes = [];
urlinfolist(1).issequence = 0;
urlinfolist(3).var_info = 1;

if exist(getarchive) == 2   
  eval(getarchive)
else
  dodsmsg('Metadata not found!')
  return
end

% for server optimization
alltime = 0;
if (getranges(4,1) <= TimeRange(1,1) & getranges(4,2) >= TimeRange(1,2))
  alltime = 1;
end

% start and end times 
beginTime = max(TimeRange(1), getranges(4,1));
lastTime = min(TimeRange(2), getranges(4,2));

% get the user selected start and end time in year/yrday/hr
StartTime = beginTime;   
startYear = floor(beginTime);
endYear = floor(lastTime);
leaps = isleap(startYear:endYear);
startYrday = (beginTime - startYear) * (365 + leaps(1));
startHr = (startYrday - floor(startYrday)) * 24;
startYrday = floor(startYrday);
endYrday = (lastTime - endYear) * (365 + leaps(length(leaps)));
endHr = (endYrday - floor(endYrday)) * 24;
endYrday = floor(endYrday);

% servers
baseservers = [];
baseservers = [urlinfolist(1).server_info];

if strcmp(str, 'url')
  % query two more times for TEMP/TEMPERATURE
  % NOTE: redundant calls seem unavoidable; other solution includes to 
  %       set up a flag to bypass 'getcat', but one more special flag 
  %       seems more undesirable
  % 1 == temp, 0 == temperature
  tempindex = [];  catstr = [];  oldcatstr = [];
  tmpvar = [];  urlvars1 = [];  urlvars2 = [];
  url = []; urls = []; lats = []; lons = []; depths = [];
  dstime = []; detime = []; stime = []; etime = [];

  oldcatstr = urlinfolist(1).catserver_info;
  prefix = urlinfolist(4).catserver_info;
  % add startdate_time and enddate_time to return
  qmark = findstr(oldcatstr, '?');
  oldcatstr = [oldcatstr(1:qmark),'DODS_StartDate_Time(', prefix, ...
	       '),DODS_EndDate_Time(',prefix, '),DODS_Latitude,'...
               'DODS_Longitude,DODS_Depth,',...
               oldcatstr(qmark+1:length(oldcatstr))];
  for i = 1:size(getvars,1)
    tmpvar = deblank(getvars(i,:));
    %%if strcmp(getarchive, 'nmfscur')
    %%  if strcmp(tmpvar, 'Sea_Temp')
    %%    catstr = strvcat([oldcatstr,'&TEMP=1'],[oldcatstr,'&TEMPERATURE=1']);
    %%  end
    %%else
      catstr = [catstr,['&',tmpvar,'=1']];
    %%end
  end
  if isempty(catstr),  catstr = oldcatstr; 
  else, catstr = [oldcatstr, catstr];  end
  for i = 1:size(catstr,1)
    loaddods(deblank(catstr(i,:)));
    if DODS_Longitude(1) ~= 0
      if findstr(catstr(i,:), 'TEMPERATURE')
        tempindex = [tempindex; 0*ones(size(DODS_Longitude))];
      else
        tempindex = [tempindex; ones(size(DODS_Longitude))];
      end
      url = strvcat(url, catstr);
      lats = [lats; DODS_Latitude];
      lons = [lons; DODS_Longitude];
      depths = [depths; DODS_Depth];
      dstime = [dstime, DODS_StartDecimal_Year];
      detime = [detime, DODS_EndDecimal_Year];
      stime = [stime, DODS_StartDate_Time];
      etime = [etime, DODS_EndDate_Time];
      urls = [urls, DODS_URL];
    end
  end

  % deref date/time and url
  urllist = []; starttimes = []; endtimes = []; 
  startdatetime = []; enddatetime = [];
  urllist = derefurl(urls);
  starttimes = derefdat(dstime);
  endtimes = derefdat(detime);
  startdatetime = derefdat(stime);
  enddatetime = derefdat(etime);

  % info in urlinfolist needs to be modified
  %     -- time
  urlinfolist(1).time_info = starttimes;
  urlinfolist(2).time_info = endtimes;
  %     -- add date_time info to (6) and (7) of time_info
  urlinfolist(6).time_info = startdatetime;
  urlinfolist(7).time_info = enddatetime;
  %     -- x/y/z dims
  urlinfolist(1).xdim_info = lons;
  urlinfolist(1).ydim_info = lats;
  urlinfolist(1).zdim_info = depths;
  %     -- urls
  urlinfolist(1).baseserver_info = urllist;
  urlinfolist(1).server_info = urllist;
  urlinfolist(1).catserver_info = url;
  %%%     -- server_no
  %%serverno = [];
  %%if isfield(urlinfolist, 'DODS_URL')
  %%  dodsurl = urlinfolist(1).DODS_URL;
  %%  if ~isempty(dodsurl)
  %%    for i = 1:size(dodsurl,1)
  %%      for j = 1:size(urllist,1)
  %%        if strcmp(deblank(dodsurl(i,:)),deblank(urllist(j,:)))
  %%          serverno = [serverno, i];
  %%        end
  %%      end
  %%    end
  %%  end
  %%end
  %%urlinfolist(2).server_info = serverno;
  %     -- tempindex,  find a place to store tempindex
  urlinfolist(4).var_info = tempindex;
  
  % tmptimes for displaying 
  %     instead of displaying all possible data, disp hourly between startTime
  %         and lastTime only to show the fact that data are collected roughly
  %         every hour
  if endYear == startYear
    tmptimes = [beginTime:1/(365+leaps(1))/24:lastTime];
  elseif endYear > startYear
    tmptime = beginTime;
    for i = 1:(endYear-startYear)
      tmptimes = [tmptimes; (tmptime:1/(365+leaps(i))/24:floor(tmptime)+1)'];
      tmptime = floor(tmptime) + 1;
    end
    tmptimes = [tmptimes; (tmptime:1/(365+leaps(i+1))/24:lastTime)'];
  end

  % construct timestr at get_data part later
  ce = [];
  for i = 1:size(urllist,1)
    ce = strvcat(ce, '   ');
    servers = strvcat(servers, urllist(i,:));
  end
  timestr = ce;
  if ~isempty(urllist)
    msg=['Time displaying on the browser is referenced hourly between the '...
         'selections.  The actual collecting times are varied and will be '...
	 'returned in get_data. '];
    dodsmsg(msg);
  end

elseif strcmp(str, 'data')

  urlinfolist(1).infotext = [];
  dstime = urlinfolist(1).time_info;
  detime = urlinfolist(2).time_info;
  stime = urlinfolist(6).time_info;
  etime = urlinfolist(7).time_info;
  urllist = urlinfolist(1).server_info;
  tempindex = urlinfolist(4).var_info;
  getvars = SelectableVariables(getvars,:);

  % calculate time index from dstime/detime/stime/etime
  syrday = date2d(stime(:,1), stime(:,2), stime(:,3));
  eyrday = date2d(etime(:,1), etime(:,2), etime(:,3));
  sleaps = isleap(stime(:,1));
  %     Now, calculate sindex and eindex based on time
  %     days :  days since stime(i)
  %     hrs  :  hr total on the first day and the last day
  %     fsec :  hr/sec of the file 
  %     usec :  hr/sec of user's selection
  %     fhrs :  hrs of the file
  %     uhrs :  hrs of user's selection
  %     syears: number of years in between start and end
  %     NOTE:   decimal years conversion is implemented for convenience 
  %             for non-hourly data, hourly data still use the long 
  %             year/yrday/hr/secs calculation for faster and more accurate 
  %             conversion.
  sindex = [];  eindex = [];  filename = [];
  for i = 1:size(stime,1)
    % ttotal is the total number of points in a day; if hourly, ttotal = 24
    ttotal = 0;
    filename = deblank(urllist(i,:));
    if findstr(filename, '3821') 
      ttotal = 60/60.4*24;
    elseif findstr(filename, '3881')  
      ttotal = 60/60.26*24; 
    elseif findstr(filename, '3931')
      ttotal = 60/59.9*24;
    elseif (findstr(filename, 'a4400401') | findstr(filename, 'aeb63710') | ...
            findstr(filename, 'rogbar8910-a') | ...
            findstr(filename, 'rogwave8910-a') | ...
            findstr(filename, 'rogwthr8910-a'))
      ttotal = 60/180*24;
    else
      ttotal = 60/60*24;   
    end
    if ttotal ~= 24
      tmpindex = 0;   tmptmpindex = 0;  syears = 0;
      if dstime(i) >= StartTime, sindex = [sindex; 0, dstime(i)];
      else
        if stime(i,1) == startYear
          tmpindex = ceil((StartTime-dstime(i))*(365+sleaps(i))*ttotal);
          sindex = [sindex;  tmpindex-1, ...
                             dstime(i)+tmpindex/24/(365+sleaps(i))];
        elseif stime(i,1) < startYear
          tmpindex = (startYear-dstime(i))*(365+sleaps(i))*ttotal;
          syears = syears + 1;
          for j = 1:(startYear-stime(i,1)-1)
            syears = syears + 1;
            if isleap(stime(i,1)+j), tmpindex = tmpindex + 366*ttotal;
            else,  tmpindex = tmpindex + 365*ttotal;  end
          end
          if isleap(startYear),  yeardays = 366;  else,  yeardays = 365;  end
          tmptmpindex = tmpindex;
          tmpindex = round(tmpindex + (StartTime-startYear)*yeardays*ttotal);
          sindex = [sindex; tmpindex-1, stime(i,1)+syears+...
                            round((tmpindex-tmptmpindex))/24/yeardays];
        end
      end
      tmpindex = 0;  tmptmpindex = 0;  syears = 0;
      if stime(i,1) < etime(i,1)     
        % file does not start and end at the same year
        if endYear == stime(i,1)    
          tmpindex = tmpindex - (dstime(i)-stime(i,1))*(365+sleaps(i))*ttotal;
        else                         
          % calculate how many days passed in the first year of the file
          tmpindex = (stime(i,1)+1-dstime(i))*(365+sleaps(i))*ttotal; 
          syears = syears + 1;
          if etime(i,1) < EndTime
            for j = 1:(etime(i,1)-stime(i,1)-1)
              syears = syears + 1;
              if isleap(stime(i,1)+j), tmpindex = tmpindex + 366*ttotal;
              else, tmpindex = tmpindex + 365*ttotal;  end
            end
          elseif etime(i,1) > EndTime
            for j = 1:(endYear-stime(i,1)-1)
              syears = syears + 1;
              if isleap(stime(i,1)+j), tmpindex = tmpindex + 366*ttotal;
              else,  tmpindex = tmpindex + 365*ttotal;  end
            end
          end
        end
      else
        tmpindex = tmpindex - (dstime(i)-stime(i,1))*(365+sleaps(i))*ttotal;
      end
      if detime(i) <= EndTime
        if isleap(etime(i,1)), yeardays = 366;  else,  yeardays = 365;  end
        tmpindex = round(tmpindex + (detime(i)-etime(i,1))*yeardays*ttotal);
        eindex = [eindex;  tmpindex-1,  detime(i)];
      elseif detime(i) > EndTime
        if isleap(endYear),  yeardays = 366;  else,  yeardays = 365;  end
        tmptmpindex = tmpindex;
        tmpindex = round(tmpindex + (EndTime-endYear)*yeardays*ttotal);
        eindex = [eindex;  tmpindex-1,  stime(i,1)+syears+...
                  round((tmpindex-tmptmpindex))/24/yeardays];
      end
    elseif ttotal == 24
      days = 0;  hrs = 0;  fhrs = 0;  uhrs = 0;  syears = 0;
      if (stime(i,1) == startYear)  
        if syrday(i) < startYrday         
          % StartTime is in the middle of the file
          % calculate how many days in between
          % first and last days are excluded
          % syrday(file) is the yrday_1;  
          % startYrday(StartTime) is the day passed, startYrday + 1 == yrday_1
          days = startYrday - syrday(i);
          if days < 0,   days = 0;  end
          % calculate the first day hrs and last day hrs
          hrs = (24-stime(i,4)) + floor(startHr);
          % if file starts at 20:30:58  and StartTime is at 20:30:59,  
          %     add one to the hrs
          fsec = stime(i,5)*60 + stime(i,6);   
          usec = (startHr-floor(startHr)) * 3600;
          if fsec < usec,  hrs = hrs + 1;  end
          % minus 1 since server begins with 0 
          sindex = [sindex; days*24 + hrs - 1, ...
                    dstime(i)+days/(sleaps(i)+365)+hrs/24/(sleaps(i)+365)];
        elseif syrday(i) == startYrday
          % calculate differeces in hrs
          fhrs = stime(i,4)*3600 + stime(i,5)*60 + stime(i,6);
          uhrs = startHr*3600;
          if (fhrs < uhrs)
            hrs = ceil((uhrs-fhrs)/3600);  
            sindex = [sindex;  hrs - 1, dstime(i)+hrs/24/(sleaps(i)+365)];
          else,   sindex = [sindex;  0, dstime(i)];   end
        elseif syrday(i) > startYrday      
          % StartTime starts before the stime of the file
          sindex = [sindex; 0, dstime(i)];
        end
      elseif (stime(i,1) < startYear)    
        % File starts year(s) before the StartTime
        % need to calculate the start index at StartTime
        % first, the days and hrs before the startYear(StartTime)
        if isleap(startYear),  yeardays = 366;  else,  yeardays = 365;  end
        if sleaps(i),  days = 366-syrday(i);  else,  days = 365-syrday(i);  end
        syears = syears + 1;
        for j = 1:(startYear-stime(i,1)-1) 
          syears = syears + 1;
          if isleap(stime(i,1)+j), days = days+366; else, days = days+365; end 
        end
        if days < 0,  days = 0;  end
        hrs = (24-stime(i,4));   fsec = stime(i,5)*60 + stime(i,6);
        % then, the days and hrs in the startYear
        days = days + startYrday;
        hrs = hrs + floor(startHr);
        usec = (startHr-floor(startHr)) * 3600;
        addhr = 0;
        if fsec < usec,  hrs = hrs + 1;  addhr = 1;  end
        sindex = [sindex; days*24 + hrs - 1, ...
                  stime(i,1)+syears+startYrday/yeardays+(floor(startHr)+...
                  addhr+fsec/3600)/24/yeardays];
      elseif (stime(i,1) > startYear)    
        % StartTime starts before the stime of the file
        sindex = [sindex; 0, dstime(i)];
      end

      days = 0;   hrs = 0;  fhrs = 0;  uhrs = 0;  syears = 0;
      % end time involves calculation of the total numbers in time (the cycle)
      % if file does not start and end at the same year, first get the days 
      %     before the end year
      if stime(i,1) < etime(i,1)     
        % file does not start and end at the same year
        if endYear == stime(i,1)    
          % user's selection is within the first year of the file
          days = -syrday(i);
        else                         
          % calculate how many days passed in the first year of the file
          if sleaps(i), days = 366-syrday(i); else, days = 365-syrday(i); end
          syears = syears + 1;
          % calculate how many days passed from the second year of the 
          %    file up to the year before the end year of user's selection
          for j = 1:(endYear-stime(i,1)-1)
            syears = syears + 1;
            if isleap(stime(i,1)+j),days = days+366;else,days = days+365;end
          end
          if days < 0,   days = 0;  end
        end
      else
        days = -syrday(i);
      end
      if (etime(i,1) == endYear)
        if isleap(endYear),  yeardays = 366;  else,  yeardays = 365;   end
        if eyrday(i) < endYrday           
          % etime of the file ends before the EndTime
          % need the total cycle
          days = days + eyrday(i) - 1;
          if days < 0,  days = 0;  end
          if days > 0,  hrs = (24-stime(i,4)) + etime(i,4); % eyrday >  syrday
          else,  hrs = etime(i,4)-stime(i,4) + 1;  end      % eyrday == syrday
          eindex = [eindex;  days*24 + hrs - 1, detime(i)];
        elseif eyrday(i) > endYrday    % EndTime is in the middle of the file
          % need the end index at the EndTime
          days = days + endYrday;
          if days < 0,  days = 0;   end
          if days > 0,  hrs = (24-stime(i,4))+floor(endHr);  % endYrday>syrday
          else,  hrs = floor(endHr)-stime(i,4)+1; end        % endYrday==syrday
          fsec = etime(i,5)*60 + etime(i,6);   
          usec = (endHr-floor(endHr)) * 3600;
          addhr = 0;
          if fsec <= usec,  hrs = hrs + 1;  addhr = 1;  end 
          eindex = [eindex;  days*24 + hrs - 1, ...
                    stime(i,1)+syears+endYrday/yeardays+(floor(endHr)+...
                    addhr+fsec/3600)/24/yeardays];
        elseif eyrday(i) == endYrday 
          days = days + eyrday(i) - 1;
          if days < 0,  days = 0;   end
          fhrs = etime(i,4)*3600 + etime(i,5)*60 + etime(i,6);
          fsec = etime(i,5)*60 + etime(i,6);
          uhrs = endHr * 3600;
          usec = (endHr - floor(endHr)) * 3600;
          if fsec <= usec,  hrs = hrs + 1;  end
          if fhrs > uhrs                
            % EndTime is in the middle of the file
            % eyrday >  syrday
            if days > 0,  hrs = (24-stime(i,4)) + floor(uhrs/3600);    
            % eyrday == syrday
            else,   hrs = floor(endHr) - stime(i,4) + 1;   end         
            eindex = [eindex;  days*24 + hrs - 1, ...
                      stime(i,1)+syears+endYrday/yeardays+(round(uhrs/3600)+...
                      fsec/3600)/24/yeardays];
          else
            if days > 0,  hrs = (24-stime(i,4)) + etime(i,4);
            else,   hrs = etime(i,4) - stime(i,4) + 1;   end
            eindex = [eindex;  days*24 + hrs - 1, detime(i)];
          end
        end
      elseif (etime(i,1) > endYear)     
        % file ends year(s) after the EndTime  
        % need to calculate the end index at the EndTime
        days = days + endYrday;
        if days > 0,  hrs = (24-stime(i,4)) + floor(endHr);% endYrday> syday
        else,  hrs = floor(endHr) - stime(i,4) + 1;   end  % endYrday==syday
        fsec = etime(i,5)*60 + etime(i,6);   
        usec = (endHr-floor(endHr)) * 3600;
        addhr = 0;
        if fsec <= usec,  hrs = hrs + 1;  addhr = 1;  end 
        if isleap(endYear),  yeardays = 366;  else,  yeardays = 365;   end
        eindex = [eindex;  days*24 + hrs - 1, ...
                  stime(i,1)+syears+endYrday/yeardays+(floor(endHr)+...
                  addhr+fsec/3600)/24/yeardays];
      elseif (etime(i,1) < endYear)     
        % file ends before the EndTime
        % need total cycle
        % need to recalculate the days, may be over added from stime to 
        %     endYear(EndTime)
        %   if etime is in between the stime and the endYear
        if syears > 0
          for j = 1:(endYear-etime(i,1))
            if isleap(endYear-j),  days = days - 366;  
            else,  days = days - 365;  end
            syears = syears - 1;
          end
        end
        days = days + eyrday(i) - 1;
        if days < 0,  days = days + 1;  end
        if days > 0,  hrs = (24-stime(i,4)) + etime(i,4);    % eyrday >  syday
        else,  hrs = etime(i,4) - stime(i,4) + 1;   end      % eyrday == syday 
        eindex = [eindex;  days*24 + hrs - 1,  detime(i)];
      end 
    end
  end

  % construct timestr and servers
  ce = [];  tmpvar = [];
  % Due to changes as to be compatible w/o loaddods -A option, 
  %     xdim/ydim/zdim info are included automatically.  Need to force 
  %     returned_var to be empty here.
  %     Originally it is not detected by the -A option because the 
  %         returned structure for NetCDF file is self-supplied;
  %         for example, the structure looks like :
  %             str.var_name.lon_name.DODS_ML_Real_Name
  %         If we know the lon_name, we don't need to eval the string 
  %         any more.
  urlinfolist(1).returned_var = [];    %12/12/2000
  % To deselect string build for depth and geo   
  urlinfolist(2).selection_info = [];  %12/12/2000
  urlinfolist(3).selection_info = [];  %12/12/2000
  for i = 1:size(urllist,1)
    ce = strvcat(ce, ['[',num2str(sindex(i),5),':',...
                      num2str(eindex(i),5),'][0][0][0]']);
    servers = strvcat(servers, urllist(i,:));
    % add time2 as one of the returned_var
    urlinfolist(1).returned_var = strvcat(urlinfolist(1).returned_var, ...
                                  [',time,time2[',num2str(sindex(i),5),':',...
                                  num2str(eindex(i),5),']']);
  end
  timestr = ce;
  urlinfolist(1).selection_info = timestr;

  % need to return sizeindex_info 
  urlsize = [];
  for i = 1:size(sindex,1)
    urlsize = [urlsize; eindex(i,1)-sindex(i,1)+1];
  end
  urlinfolist(1).sizeindex_info = urlsize;
  urlinfolist(2).sizeindex_info(:,1) = sindex(:,1);
  urlinfolist(2).sizeindex_info(:,2) = eindex(:,1);
  urlinfolist(2).sizeindex_info(:,3) = sindex(:,2);
  urlinfolist(2).sizeindex_info(:,4) = eindex(:,2);

elseif strcmp(str, 'value')

  newtime2 = []; newdstime = []; newdetime = [];  newvars = [];
  newvars = varargin{5};
  newtime = newvars.t3;
  newtime2 = newvars.t4;
  newdstime = urlinfolist(2).sizeindex_info(:,3);
  newdetime = urlinfolist(2).sizeindex_info(:,4); 

  tmptime = []; tmpdtime = [];
  tmptime = invjul(newtime);
  if ~isempty(tmptime)
    years = floor(tmptime);
    leaps = 365 + isleap(years);
    % adds up date (from newtime) and newtime2 (1000secs since the day starts)
    tmp = newtime2/1000/3600/24/leaps;
    tmpdtime = tmptime + (newtime2./leaps)/1000/3600/24;
  end

  tmptimes = tmpdtime;
  urlinfolist(5).time_info = tmptimes;

end

return


% $Log: nfcurt.m,v $
% Revision 1.1  2002/04/15 20:05:57  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.4  2002/04/11 17:04:11  dan
% Removed reference to variable times. It was never used; only initialized.
%
% Revision 1.3  2000/12/21 16:33:19  kwoklin
% Manage to be compatible with loaddods w/o -A option. If the option is used,
% lines command with 12/12/2000 date should be re/un/commanded accordindly. klee
%
% Revision 1.2  2000/11/15 15:49:27  kwoklin
% Fix a type-o.   klee
%
% Revision 1.1  2000/11/14 19:27:19  kwoklin
% First toolbox internal release.  Note that the TEMP/TEMPERATURE switch
% for nmfscur is disabled in the hope that the data files would be self-
% corrected in the near future.   klee
%

