%
%  NMFS Moored Current Meter Projects from 1977 to 1999

%
% $Id: nmfscur.m,v 1.1 2002/04/15 20:00:15 dan Exp $
% klee 11/06/2000
% klee 01/28/2000

GetFunctionName = 'getjgsta';
Cat_m_File = 'gbcat';
URL_m_File = 'gburl';
CatalogServer = 'http://dods.gso.uri.edu/cgi-bin/nph-ff/catalog/nmfscurrent.dat';
Catvars = str2mat('DODS_URL','DODS_Latitude','DODS_Longitude','DODS_Depth');
Catselc = str2mat('date_range');
Catstr = 'NMFS_CURRENT';

LonRange = [-74 -65];
LatRange = [40.0 42.5];
TimeRange = [1976.24544627 2000];
DepthRange = [19 895];
DepthUnits = 'Meters';
Resolution = nan;
Prefix = 'NMFS_CURRENT';

DataName = 'Water Column - NMFS Woods Hole Current Meter Projects - NMFS';
TimeName = '';
LongitudeName = 'lon';
LatitudeName = 'lat';
DepthName = 'depth';
DodsName = str2mat('EAST','NORTH','TEMP','TEMPERATURE');
SelectableVariables = str2mat('U_Current','V_Current','Sea_Temp','Sea_Temp');
% a workaround, since getjgsta is originally designed for jg/ff servers, 
%     and the server for this data set is nc, time variables need to be
%     declared explicitly.
OptionalVariables = str2mat('time2','time');
SelectableOptional = str2mat('time2','time');
TimeInfo_File = 'nfcurt';

Acknowledge = sprintf('%s\n\n%s%s%s%s%s%s', ...
    [ 'The authors of this dataset is J. Manning. ', ...
      'The data were provided by the NMFS Woods Hole Field Center ', ...
      '(http://www.wh.whoi.edu/~jmanning/foi/currents.html), ', ...
      'and accessed via the Distributed Oceanographic Data System ',...
      '(DODS: http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citation:  Ramp, S.R., R.J.Schlitz, and W.R.Wright, 1985, ',...
      'The Deep Flow through the Northeast Channel, Gulf of Maine, ',...
      'Jour. of Phys. Ocean., 15(12):1790-1808.'],...
    [ 'Manning, J.P. and R. Beardsley, 1996, Assessment of Georges ',...
      'Bank Recirculation from Eulerian Current Observations in the ',...
      'Great South Channel, Deep Sea ResII, Vol. 43(7-8):1575-1600.'],...
    [ 'Manning,J.P., L.Y. Oey, D. Packer, J. Vitaliano, T.W. Finneran,',...
      'K.W.You, and S. Fromm, 1994, Observations of Bottom Currents ',...
      'and Estimates of Resuspended Sediment Transport at the New ',...
      'York Bight 12-mile Dumpsite, JGR, 99(C5):10,221-10,239.'], ...
    [ 'Manning, J.P., T.Holzwarth-Davis, M.Taylor, T.Rotunno, ',...
      'D.Mountain, R.G.Lough, 1995, Georges Bank Stratification Study: ',...
      '1992 Data Report, Northeast Fisheries Science Center Reference ',...
      'Document 95-12.'], ...
    [ 'Schlitz, R., J.P. Manning, and K.Smith, 2000, Structure and ',...
      'transport of Alongshelf currents across the Southern Flank of ',...
      'Georges Bank during late summer, DSRII,in press..'], ...
    [ 'Werner,S.R., 1999, Surface and bottom boundary layer dynamics ',...
      'on a shallow submarine bank: southern flank of Georges bank, ',...
      'PhD. Thesis. MIT/WHOI, 99-13.']);
Data_Use_Policy = [];

Comments1 = sprintf('%s\n', ...
'                     NMFS Woods Hole Current Meter Projects ', ...
'    ',...
'           Parameter         Description                    Units',...
'      --------------------------------------------------------------------------',...
'           time              True Julian day                 days',...
'           time2             msec since 0:00 GMT            msecs',...
'           decimal_year      decimal year days              yrdays',...
'           lon               longitude                      degrees east',...
'           lat               latitude                       degrees north',...
'           instdepth         instrument depth               meters from sea level',...
'           wdepth            water depth                    meters from sea level',...
'           EAST              eastward current velocity      cm/s',...
'           NORTH             northward current velocity     cm/s',...
'           TEMP(TEMPERATURE) sea water temperature          degrees C',...
'     ');

Comments2 = sprintf('%s\n', ...
'     ',...
'    For more information about the stations and vertical configurations, please',...
'refer to http://www.wh.whoi.edu/~jmanning/foi/currents.html');

Comments3 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Mar. 30, 1976 (1976.24544627) ', ...
'         Ending_Date:    Nov. 17, 1996 (1996.87805365)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: -69.317  W ', ...
'              East Bounding Coordinate: -68.348  W ', ...
'              South Bounding Coordinate: 40.483  N ', ...
'              North Bounding Coordinate: 40.883  N ', ...
'    Temporal Resolution: 1 hour', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               James Manning', ...
'               NMFS ', ...
'               Woods Hole, MA 02543 ', ...
'               USA ', ...
'               FAX : 508-495-2258 ', ...
'               Electronic Mail Address: INTERNET > jmanning@whsun1.wh.whoi.edu', ...
'         Address - dods: ',...
'               Electronic Mail Address: INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2 Comments3];


% $Log: nmfscur.m,v $
% Revision 1.1  2002/04/15 20:00:15  dan
% These data sets do not work, so I moved them to the BROKEN_DATASET directory.
%
% Revision 1.2  2000/12/21 16:40:16  kwoklin
% Add Catvars, Catselc, Catstr and uncommand Time/Lon/Lat names for
% compatibility with loaddods w/o -A option.  If the option is used,
% Catxxx should be commanded out.                              klee
%
% Revision 1.1  2000/11/14 19:27:19  kwoklin
% First toolbox internal release.  Note that the TEMP/TEMPERATURE switch
% for nmfscur is disabled in the hope that the data files would be self-
% corrected in the near future.   klee
%
