%
%                            GFDL Ocean Assimilation (T,S)

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';

% VARIABLES -- OPTIONAL
Server = 'http://nomads.gfdl.noaa.gov/cgi-bin/nph-nc/dods-data/gfdl_ocean_assimilation/time_mean.001986.nc';
% Nlon = 360;
% Nlat = 200;

% VARIABLES -- REQUIRED
LonRange = [0 360];
LatRange = [-76 66];
TimeRange = [1986 1987];
DepthRange = [0 5000];
DepthUnits = 'Meters';
Resolution = 111.0;

DataName = 'GFDL Ocean Assimilation';
% TimeName = 'Time';
% LongitudeName = 'xt_i';
% LatitudeName = 'yt_j';
% DepthName = 'zt_k';

%        Float32 temp[Time = 12]  [zt_k = 40][yt_j = 200][xt_i = 360];
%    Float32 salinity[Time = 12]  [zt_k = 40][yt_j = 200][xt_i = 360];
%           Float32 u[Time = 12]  [zt_k = 40][yu_j = 200][xu_i = 360];
%           Float32 v[Time = 12]  [zt_k = 40][yu_j = 200][xu_i = 360];
%           Float32 w[Time = 12]  [zw_k = 40][yt_j = 200][xt_i = 360];
%        Float32 hflx[Time = 12][Surface = 1][yt_j = 200][xt_i = 360];
%        Float32 sflx[Time = 12][Surface = 1][yt_j = 200][xt_i = 360];
%        Float32 taux[Time = 12][Surface = 1][yu_j = 200][xu_i = 360];
%        Float32 tauy[Time = 12][Surface = 1][yu_j = 200][xu_i = 360];
%       Float32 convU[Time = 12][Surface = 1][yt_j = 200][xt_i = 360];
%        Float32 psiu[Time = 12][Surface = 1][yt_j = 200][xt_i = 360];
%        Float32 psiv[Time = 12][Surface = 1][yt_j = 200][xt_i = 360];
%         Float32 sff[Time = 12][Surface = 1][yt_j = 200][xt_i = 360];
%         Float32 eta[Time = 12]             [yt_j = 200][xt_i = 360];
%        Float32 hmxl[Time = 12]             [yt_j = 200][xt_i = 360];
%        Float32 hblt[Time = 12]             [yt_j = 200][xt_i = 360];
%      Float32 period[Time = 12];

%SelectableVariables = str2mat('Sea_Temp', 'Salinity', 'Current_U', 'Current_V', ...
%  'Current_W', 'Surface_Heat_Flux', 'Surface_Salt_Flux', 'Wind_Stress_U', ...
%  'Wind_Stress_V', 'Convergence_of_H*ubar', 'Streamfunction_for_H*ubar', ...
%  'Streamfunction_for_H*vbar', 'Fresh_water_flux', 'Surface_height', ...
%  'Mixed_layer_depth', 'Boundary_layer_depth');

SelectableVariables = str2mat('Sea_Temp', 'Salinity');

% there must be one DODSNAME for each selectable variable
%DodsName = str2mat('temp','salinity','u','v','w','hflx','sflx','taux', ...
%           'tauy','convU','psiu','psiv','sff','eta','hmx','hblt');

DodsName = str2mat( 'temp', 'salinity');

% note: DataNull is applied *before* scaling
DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
[DataNull(5:length(DataNull))] = deal({-9999999790214767953607394487959552.0});

Data_Use_Policy = '';

Acknowledge = sprintf('%s\n%s\n%s\n%s\n%s', ...
    [ 'These data were prepared by Sydney Levitus, Timothy Boyer, ', ...
      'Russell Burgett, and Margarita Conkright of the National ', ...
      'Oceanographic Data Center (NODC). ', ...
      'and provided by the Ferret development group of ', ...
      'the Thermal Modeling and Analysis Project at NOAA''s Pacific ', ...
      'Marine Environmental Laboratory in Seattle Washington (PMEL: ', ...
      'http://www.pmel.noaa.gov  Ferret: http://ferret.pmel.noa.gov).', ...
      '  The data were accessed via the Distributed Oceanographic Data ',...
      'System (DODS: http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citations: ', ...
      'Conkright, M.E., S. Levitus and T.P. Boyer.  1994. World Ocean Atlas',...
      '1994 Volume 1: Nutrients.  NOAA Atlas NESDIS 1.  U.S. Department of',...
      'Commerce, Washington, D.C.  150 pp.'],...
    [ 'Levitus S. and T.P. Boyer.  1994a. World Ocean Atlas 1994 Volume 2:',...
      'Oxygen. NOAA Atlas NESDIS 2.  U.S. Department of Commerce, Washington,',...
      'D.C.  186 pp.'],...
    [ 'Levitus S., R. Burgett and T.P. Boyer.  1994b. World Ocean Atlas 1994',...
      'Volume 3: Salinity. NOAA Atlas NESDIS 3.  U.S. Department of Commerce,',...
      'Washington, D.C.  99 pp.'],...
    [ 'Levitus S. and T.P. Boyer.  1994c. World Ocean Atlas 1994 Volume 4:',...
      'Temperature.  NOAA Atlas NESDIS 4.  U.S. Department of Commerce,',...
      'Washington, D.C. 117 pp.']);
% COMMENTS
Comments1 = sprintf('%s\n', ...
    '                       World Ocean Atlas (1994)', ...
    '                              Monthly fields', ...
    '    ', ...
    '    The WOA94 climatology is constructed using high-quality research data from', ...
    '    NODC archives that was collected using XBTs, CTDs, and hydrographic bottles',...
    '    between 1900 and the first quarter of 1993 (Levitus and Boyer 1994).  Most ',...
    '    observations, however, were collected after 1950.  Observations were binned ',...
    '    in a one-degree grid over the entire globe and compared with a "first-guess"',...
    '    estimate based on one-degree zonal averages for the ocean basin in question.',...
    '    A correction factor based on the difference between the "first-guess" and ',...
    '    the one-degree square mean was applied to the "first-guess" parameter, and ',...
    '    the results were median filtered to yield monthly climatologies resolved at ',...
    '    one degree in latitude and longitude. The WOA94 procedures were developed ',...
    '    and applied to not only create surface climatologies but those at standard ',...
    '    depth levels to 1000m as well. ', ...
    '     ', ...
    '    The dataset consists of temperature and salinity in the',...
    '    world ocean. It was prepared by Sydney Levitus, Timothy Boyer, Russell Burgett,', ...
    '    and Margarita Conkright of the National Oceanographic Data Center (NODC). The ', ...
    '    atlas continues and extends the 1982 Climatological Atlas by Levitus.');

Comments2 = sprintf('%s\n', ...
    '    ', ...
    '    [Excerpt] Table 1.  Precision and number of profiles for each parameter.', ...
    '    ----------------------------------------------------------------',...
    '                                                      Maximum',...
    '                                                        stored        # of',...
    '    Parameter            Unit               precision         Profiles',...
    '    ----------------------------------------------------------------',...
    '    Temperature         degrees C             xx.xxx      4,553,426',...
    '    Salinity                     p.s.u.                xx.xxx      1,254,771',...
    '    ----------------------------------------------------------------',...
    '    (from the Lamont Ocean Climate Library,', ...
    '    http://ingrid.ldeo.columbia.edu/SOURCES/.LEVITUS94/.dataset_documentation.html)',...
    '    ',...
    '    The standard depths at which these observations have been ',...
    '    gridded are (in meters): 0, 10, 20, 30, 50, 75, 100, 125, ',...
    '    150, 200, 250, 300, 400, 500, 600, 700, 800, 900, and 1000.');
    
Comments3 = sprintf('%s\n', ...
    '       ',...
    '                         References',...
    '       ',...
    '    Conkright, M.E., S. Levitus and T.P. Boyer.  1994. World Ocean Atlas',...
    '     1994 Volume 1: Nutrients.  NOAA Atlas NESDIS 1.  U.S. Department of',...
    '     Commerce, Washington, D.C.  150 pp.',...
    '    ',...
    '     Levitus S. and T.P. Boyer.  1994a. World Ocean Atlas 1994 Volume 2:',...
    '     Oxygen. NOAA Atlas NESDIS 2.  U.S. Department of Commerce, Washington,',...
    '     D.C.  186 pp.',...
    '    ',...
    '     Levitus S., R. Burgett and T.P. Boyer.  1994b. World Ocean Atlas 1994',...
    '     Volume 3: Salinity. NOAA Atlas NESDIS 3.  U.S. Department of Commerce,',...
    '     Washington, D.C.  99 pp.',...
    '     ',...
    '     Levitus S. and T.P. Boyer.  1994c. World Ocean Atlas 1994 Volume 4:',...
    '     Temperature.  NOAA Atlas NESDIS 4.  U.S. Department of Commerce,',...
    '     Washington, D.C. 117 pp.',...
    '    ',...
    '     Levitus, S., R. Gelfeld, T. Boyer and D. Johnson.  1994e.  Results of the',...
    '     NODC and IOC Oceanographic Data Archaeology and Rescue Projects.  Key',...
    '     to Oceanographic Records Documentation No. 19, NODC, Washington, D.C.',...
    '     ',...
    '     Levitus, S. and R. Gelfeld.  1992.  NODC Inventory of Physical',...
    '     Oceanographic Profiles.  Key to Oceanographic Records Documentation No. 18,',...
    '     NODC, Washington, D.C.',...
    '    ',...
    '     Boyer, T.P. and S. Levitus.  1994.  Quality control and processing of',...
    '     historical temperature, salinity and oxygen data.  NOAA',...
    '     Technical Report NESDIS 81.  U.S. Department of Commerce. Washington,',...
    '     D.C.  65 pp.',...
    '     ',...
    '     Conkright, M.E., T.P. Boyer and S. Levitus.  1994.  Quality control',...
    '     and processing of historical nutrient data.  NOAA Technical Report',...
    '     NESDIS 79.  U.S. Departement of Commerce, Washington, D.C. 75 pp.');

Comments4 = sprintf('%s\n', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1935 ', ...
'         Ending_Date:1978 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:0.0 ', ...
'              East Bounding Coordinate:360.0 ', ...
'              South Bounding Coordinate:-90.00 ', ...
'              North Bounding Coordinate:+90.00 ', ...
'   ', ...
'    Point_of_Contact (Science) = Sydney Levitus', ...
'         Address: E/OC5', ...
'                  National Oceanographic Data Center', ...
'                  RM 4363 Bldg SSMC3', ...
'                  1315 East-West Highway',...
'                  Silver Spring, MD 20910-3282',...
'                  USA',...
'               Telephone: (202) 626-4411', ...
'               Telephone: (202) 673-5411', ...
'         Electronic Mail Address:INTERNET > Sydney.Levitus@noaa.gov', ...
'     ',...
'    Point_of_Contact (Data Provision) = ', ...
'         Address: ', ...
'               Kevin O''Brien ', ...
'               NOAA/PMEL', ...
'               7600 Sand Point Way NE', ...
'               Seattle, Washington 98115-0070', ...
'               USA ', ...
'               Telephone: (206) 526-6751', ...
'         Electronic Mail Address:INTERNET > ferret@pmel.noaa.gov');

Comments = [Comments1 Comments2 Comments3 Comments4];

