%
%  USGS Moored Hourly Time Series Data

%
% $Id: usgstsm.m,v 1.1 2002/04/15 20:07:14 dan Exp $
% klee 08/11/99

GetFunctionName = 'getjgsta';
Cat_m_File = 'gbcat';
URL_m_File = 'gburl';
CatalogServer = 'http://dods.gso.uri.edu/cgi-bin/nph-ff/catalog/usgstseries.dat';
Catvars = str2mat('DODS_URL','DODS_Latitude','DODS_Longitude','DODS_Depth');
Catselc = str2mat('date_range');
Catstr = 'USGS_TSERIES';

LonRange = [-169 -41];
LatRange = [16 45];
TimeRange = [1973.16672 1998.08265];
DepthRange = [0 -13];
DepthUnits = 'Meters';
Resolution = nan;
Prefix = 'USGS_TSERIES';

DataName = 'MET - Coastal Marine Time Series - USGS';
TimeName = str2mat('time','time2','decimal_year');
LongitudeName = 'lon';
LatitudeName = 'lat';
DepthName = 'depth';
DepthFlag = [0;0;1;0;0];
DodsName = str2mat(str2mat('T_25','AT_21'),...
                   str2mat('WS_400','WD_410','WU_422','WV_423','Tx_446',...
                           'Ty_447'),...
                   str2mat('wp_4060','wh_4061'));
SelectableVariables = str2mat(str2mat('Sea_Surface_Temp','Air_Temp'),...
                              str2mat('Wind_Speed','Wind_Dir','U_Wind',...
                                      'V_Wind','Wind_Stress_Zonal',...
                                      'Wind_Stress_Merid'),...
                              str2mat('Wave_Period_Avg','Wave_Height'));
OptionalVariables = str2mat('time2','time','wdepth');
SelectableOptional = str2mat('time2','time','Depth_Water');
TimeInfo_File = 'nfcurt';

DataNull = [nan nan nan nan ...
            -9999 -9999 nan nan nan nan nan nan nan 9999 ...
            nan nan nan];

Acknowledge = sprintf('%s\n', ...
    [ 'The authors of this dataset is R. Signell ', ...
      'The data were provided by the USGS Woods Hole Field Center ', ...
      '(http://crusty.er.usgs.gov/epic/), and accessed via', ...
      'the Distributed Oceanographic Data System (DODS: ', ...
      'http://www.unidata.ucar.edu/packages/dods).']);
Data_Use_Policy = [];

Comments1 = sprintf('%s\n', ...
'                        USGS Coastal Marine Time Series ', ...
'    ',...
'           Parameter         Description                    Units',...
'      --------------------------------------------------------------------------',...
'           time              True Juian day                 days',...
'           time2             msec since 0:00 GMT            msecs',...
'           decimal_year      decimal year days              yrdays',...
'           lon               longitude                      degrees east',...
'           lat               latitude                       degrees north',...
'           depth             instrument depth               meters from sea level',...
'           wdepth            water depth                    meters from sea level',...
'           T_25              sea surface temperature        degrees C',...
'           AT_21             air temperature                degrees C',...
'           WS_400            wind speed                     cm/s',...
'           WD_410            wind direction                 degrees, 0-360 degrees',...
'           WU_422            U wind speed                   cm/s',...
'                             (oceanographic sense, going to)',...
'           WV_423            V wind speed                   cm/s',...
'           Tx_446            zonal true wind stress         m^2/s^2',...
'           Ty_447            meridional true wind stress    m^2/s^2',...
'           P_4020            avg relative pressure          mbar',...
'                             (burst pressure minus interval pressure, Seadata tripod)',...
'           wp_4060           avg wave period                sec',...
'           wh_4061           significant wave height        meters',...
' ',...
' ',...
'                  Time-series data collected by the USGS or used in conjunction',...
'                  with USGS projects. ',...
'                  These data are stored as NetCDF',...
'                  ("http://www.unidata.ucar.edu/packages/netcdf/index.html")',...
'                  files using conventions developed by NOAA''s PMEL lab to be',...
'                  compatible with their EPIC ("http://www.pmel.noaa.edu/epic")',...
'                  system.  ',...
'                  The hourly data is available online at "http://crusty.er.usgs.gov/epic/".',...    
'    ');

Comments2 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Mar. 02, 1973 (1973.16672) ', ...
'         Ending_Date:    Jan. 31, 1998 (1998.08365)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 168.5102 W ', ...
'              East Bounding Coordinate:  42.3947 W ', ...
'              South Bounding Coordinate: 17.1622 N ', ...
'              North Bounding Coordinate: 43.8437 N ', ...
'    Temporal Resolution: 1 hour', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               Rich Signell', ...
'               384 Woods Hole Road', ...
'               U.S. Geological Survey', ...
'               Woods Hole, MA 02543 ', ...
'               USA ', ...
'               Electronic Mail Address: INTERNET > rsignell@crusty.er.usgs.gov ', ...
'               Web Page URL: http://crusty.er.usgs.gov/rsignell.html ', ...
'         Address - technical: ', ...
'               Fran Hotchkiss', ...
'               384 Woods Hole Road', ...
'               U.S. Geological Survey', ...
'               Woods Hole, MA 02543 ', ...
'               USA ', ...
'               Electronic Mail Address: INTERNET > fhotchkiss@usgs.gov', ...
'         Address - dods: ',...
'               Electronic Mail Address: INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2];


% $Log: usgstsm.m,v $
% Revision 1.1  2002/04/15 20:07:14  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.2  2000/12/21 16:40:16  kwoklin
% Add Catvars, Catselc, Catstr and uncommand Time/Lon/Lat names for
% compatibility with loaddods w/o -A option.  If the option is used,
% Catxxx should be commanded out.                              klee
%
% Revision 1.1  2000/11/14 19:27:19  kwoklin
% First toolbox internal release.  Note that the TEMP/TEMPERATURE switch
% for nmfscur is disabled in the hope that the data files would be self-
% corrected in the near future.   klee
%
% Revision 1.3  2000/04/14 18:27:16  kwoklin
% Adding nmfsctd.  Data in usgstseries are revised.
% Cat files changes accordingly.   klee
%
