%
%  USGS Moored Hourly Time Series Data

%
% $Id: usgstsw.m,v 1.1 2002/04/15 20:07:14 dan Exp $
% klee 11/08/2000
% klee 08/11/1999

GetFunctionName = 'getjgsta';
Cat_m_File = 'gbcat';
URL_m_File = 'gburl';
CatalogServer = 'http://dods.gso.uri.edu/cgi-bin/nph-ff/catalog/usgstseries.dat';
Catvars = str2mat('DODS_URL','DODS_Latitude','DODS_Longitude','DODS_Depth');
Catselc = str2mat('date_range');
Catstr = 'USGS_TSERIES';

LonRange = [-169 -41];
LatRange = [16 45];
TimeRange = [1973.16672 1998.08265];
DepthRange = [0 949];
DepthUnits = 'Meters';
Resolution = nan;
Prefix = 'USGS_TSERIES';

DataName = 'Water Column - Coastal Marine Time Series - USGS';
TimeName = '';
LongitudeName = 'lon';
LatitudeName = 'lat';
DepthName = 'depth';
DodsName = str2mat(str2mat('u_1205','v_1206','w_1204','CS_300','CD_310',...
                           'T_20'),...
                   str2mat('S_40','C_50','ST_70','STH_71','O_60','OST_62'),...
                   str2mat('ATTN_55','ptrn_4011','rtrn_4012','NEP_56'),...
                   str2mat('P_4023','SDP_850'),...
                   str2mat('SV_80','FAC_81'),...
                   'SL_7');
                   %str2mat('tiltx_4017','tilty_4018','comp_1404'),...
SelectableVariables = str2mat(str2mat('U_Current','V_Current','W_Current',...
                              'Current_Speed','Current_Dir','Sea_Temp'),...
                        str2mat('Salinity','Conductivity','Sigma_T',...
                              'Sigma_Theta','Dissolved_Oxygen',...
                              'Oxygen_Saturation'),...
                        str2mat('Beam_Attenuation','Percent_Transmission',...
                               'Raw_Transmission','Backscatter_Intensity'),...
                        str2mat('Burst_Pressure','STD_Burst_Pressure'),...
                        str2mat('Sound_Velocity','Sound_Speed_Corr_Factor'),...
                               'Sea_Level_Anomaly');
                              %str2mat('Tiltx','Tilty','Compass'),...
OptionalVariables = str2mat('time2','time');
SelectableOptional = str2mat('time2','time');
TimeInfo_File = 'nfcurt';


Acknowledge = sprintf('%s\n', ...
    [ 'The authors of this dataset is R. Signell ', ...
      'The data were provided by the USGS Woods Hole Field Center ', ...
      '(http://crusty.er.usgs.gov/epic/), and accessed via', ...
      'the Distributed Oceanographic Data System (DODS: ', ...
      'http://www.unidata.ucar.edu/packages/dods).']);
Data_Use_Policy = [];

Comments1 = sprintf('%s\n', ...
'                        USGS Coastal Marine Time Series ', ...
'    ',...
'           Parameter         Description                    Units',...
'      --------------------------------------------------------------------------',...
'           time              True Juian day                 days',...
'           time2             msec since 0:00 GMT            msecs',...
'           decimal_year      decimal year days              yrdays',...
'           lon               longitude                      degrees east',...
'           lat               latitude                       degrees north',...
'           depth             instrument depth               meters from sea level',...
'           wdepth            water depth                    meters from sea level',...
'           u_1205            eastward current velocity      cm/s',...
'           v_1206            northward current velocity     cm/s',...
'           w_1204            vertival current velocity      cm/s',...
'           CS_300            current speed                  cm/s',...
'           CD_310            current direction              degrees, true north',...
'           T_20              sea water temperature          degrees C',...
'           S_40              salinity                       ppt',...
'           C_50              conductivity                   mmho/cm',...
'           ST_70             Sigma_T                        kg/m^3',...
'           STH_71            Sigma_Theta                    kg/m^3',...
'           O_60              oxygen                         ml/L',...
'           OST_62            oxygen                         % saturation',...
'           ATTN_55           beam attenuation               m^(-1)',...
'           ptrn_4011         percent transmission (normal-  %',...
'                             lized by 95% air transmission)',...
'           rtrn_4012         raw transmissometer            volts',...
'           NEP_56            backscatter intensity          v',...
'           P_4023            average burst pressure         mbar',...
'           SDP_850           stddev of burst pressure       mbar',...
'           SV_80             sound velocity                 m/s',...
'           FAC_81            sound speed corr. factor       ',...
'                             (corr. BASS current for actual sound speed)',...
'           SL_7              sea level anomaly              meters',...
'           van_1403          vane angle                     degrees',...
'                             (current orientation to instrument)',...
'           bear_1411         bearing                        degreeM',...
'                             (instant. dir., magnetic north)',...
'           rot_4005          rotor counts                   counts',...
'                             (vacm rotor counter)',...
'           upr_4001          upper rotor speed              cm/s',...
'                             (interval upper rotor speed, Seadata tripod)',...
'           lowr_4002         lower rotor speed              counts',...
'                             (basic measurement, vmcm)');

Comments2 = sprintf('%s\n', ...
'           lowr_4003         lower rotor speed              cm/s',...   
'           stead_4009        steadiness                     ',...
'                             (vacm rotor spd normalized by vector spd to measure wave effect)',...
'           rdif_4004         rotor speed difference         cm/s',...
'           rot_4005          rotor counts                   counts',...
'                             (vacm rotor counter)',...
'           rspd_4006         rotor speed                    cm/s',...
'                             (scalar speed from rotor counts)',...
'  ',...
'  ',...
'                  Time-series data collected by the USGS or used in conjunction',...
'                  with USGS projects. ',...
'                  These data are stored as NetCDF',...
'                  ("http://www.unidata.ucar.edu/packages/netcdf/index.html")',...
'                  files using conventions developed by NOAA''s PMEL lab to be',...
'                  compatible with their EPIC ("http://www.pmel.noaa.edu/epic")',...
'                  system.  ',...
'                  The hourly data is available online at "http://crusty.er.usgs.gov/epic/".',...    
'    ');

Comments3 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Mar. 02, 1973 (1973.16672) ', ...
'         Ending_Date:    Jan. 31, 1998 (1998.08365)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 168.5102 W ', ...
'              East Bounding Coordinate:  42.3947 W ', ...
'              South Bounding Coordinate: 17.1622 N ', ...
'              North Bounding Coordinate: 43.8437 N ', ...
'    Temporal Resolution: 1 hour', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               Rich Signell', ...
'               384 Woods Hole Road', ...
'               U.S. Geological Survey', ...
'               Woods Hole, MA 02543 ', ...
'               USA ', ...
'               Electronic Mail Address: INTERNET > rsignell@crusty.er.usgs.gov ', ...
'               Web Page URL: http://crusty.er.usgs.gov/rsignell.html ', ...
'         Address - technical: ', ...
'               Fran Hotchkiss', ...
'               384 Woods Hole Road', ...
'               U.S. Geological Survey', ...
'               Woods Hole, MA 02543 ', ...
'               USA ', ...
'               Electronic Mail Address: INTERNET > fhotchkiss@usgs.gov', ...
'         Address - dods: ',...
'               Electronic Mail Address: INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2 Comments3];



% $Log: usgstsw.m,v $
% Revision 1.1  2002/04/15 20:07:14  dan
% Does not work in browser, so I moved to BROKEN_DATASETS directory.
%
% Revision 1.3  2000/12/27 21:03:10  kwoklin
% Fix an unmatched SVariables.   klee
%
% Revision 1.2  2000/12/21 16:40:16  kwoklin
% Add Catvars, Catselc, Catstr and uncommand Time/Lon/Lat names for
% compatibility with loaddods w/o -A option.  If the option is used,
% Catxxx should be commanded out.                              klee
%
% Revision 1.1  2000/11/14 19:27:19  kwoklin
% First toolbox internal release.  Note that the TEMP/TEMPERATURE switch
% for nmfscur is disabled in the hope that the data files would be self-
% corrected in the near future.   klee
%
