%
%               FILE DESCRIBING THE GODDARD SNOW DEPTH 

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
Cat_m_File = 'ffcsquery';

% VARIABLES -- OPTIONAL
CatalogServer = 'http://daac.gsfc.nasa.gov/daac-bin/nph-ff/DODS/catalog/smmr_snow-cat.dat';

Nlon = 360;
Nlat = 180;
axes_order = [2 1 0 0];

% VARIABLES -- REQUIRED
LonRange = [-180 180];
LatRange = [90 -90];
TimeRange = [1978+10*30/365 1987+8*30/365];
DepthRange = [0 0];
Resolution = 111.0;

DataName = 'SMMR Snow Depth - GSFC';
SelectableVariables = str2mat('Snow_Depth');
DodsName = 'smmr_snow';

% note: DataNull is applied *before* scaling
DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
DataNull(5) = {[-999.9000244140625 -99 254]};
DataScale = [NaN NaN; ...
             NaN NaN; ...
             NaN NaN; ...
             NaN NaN; ...
             NaN NaN];

Acknowledge = sprintf('%s\n', ...
[' The authors wish to thank the original data producer, Dr. Alfred Chang of the ',...
 'Hydrological Sciences Branch at NASA Goddard Space Flight Center in Greenbelt, MD. ',...
 'The Distributed Active Archive Center (Code 902) at Goddard Space Flight Center, ',...
 'Greenbelt, MD, 20771, acquired this dataset from the National Snow and Ice Data ',...
 'Center (NSIDC) and put it in the present format for distribution. Goddard DAAC''s ',...
 'share in these activities was sponsored by NASA''s Mission to Planet Earth program.']); 

% COMMENTS
Comment1 = sprintf('%s\n', ...
'                            SMMR Snow Depth in Centimeters', ...
' ', ...
'   The data set consists of one degree by one degree gridded global monthly averaged snow ',...
' depths derived from the Nimbus-7 Scanning Multichannel Microwave Radiometer (SMMR) half ',...
' degree by half degree gridded snow depth data. ',...
' ', ...
'   The SMMR sensor was placed in an alternate-day operating pattern on 19 November 1978 due ',...
' to spacecraft power limitations, providing complete global coverage every six days. Regions ',...
' poleward of 72 degrees have complete coverage for each day the sensor was recording data. ',...
' The SMMR data spans over the period from 1978 through 1987.');

Comment2 = sprintf('%s\n', ...
' ', ...
'   The algorithm used to retrieve snow depth on a global scale using the remotely sensed ',...
' microwave signals has been developed by a group of NASA scientists (Chang et al., 1976,',...
' 1982,1987,1990, 1992; Foster et al., 1984; Hall et al., 1982). Data are placed into 1/2 ',...
' degree latitude by 1/2 degree longitude grid cells. SMMR data were interpolated for ',...
' spatial and temporal gaps. Overlapping data in a cell from separate orbits within the ',...
' same six-day period are averaged to give a single brightness temperature, assumed to ',...
' be at the center of the cell. Maps are based on six-day average brightness temperature ',...
' data from the middle week of each month. Oceans and bays are masked so that only ',...
' microwave data for land areas are distinct. ');

Comment3 = sprintf('%s\n', ...
' ', ...
'   Comparisons of SMMR snow maps with previous maps produced by NOAA/NESDIS and US Air Force ',...
' Global Weather Center indicate that the total snow derived from SMMR is usually about ten ',...
' percent less than that measured by the earlier products, because passive microwave sensors ',...
' often can''t detect shallow dry snow less than about 5 cm deep. SMMR snow depth results are ',...
' especially good for uniform snow covered areas such as the Canadian high plains and Russian ',...
' steppes. Heavily forested and mountainous areas tend to mask the microwave snow signatures, ',...
' and SMMR snow depth derivations are poorer in those areas.',...
' ', ...
'   For more information see: ', ...
' http://daac.gsfc.nasa.gov/CAMPAIGN_DOCS/FTP_SITE/INT_DIS/readmes/smmr_snow.html#200');

Comments = [Comment1 Comment2 Comment3];

