%
%                            SODA Ocean Model (T)

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';

% VARIABLES -- OPTIONAL
%Server = 'http://dods.gso.uri.edu:8080/dodsC/SODA';
Server = ...
str2mat('http://apdrc.soest.hawaii.edu/cgi-bin/nph-nc/data/soda/soda_tmp.cdf', ...
	'http://apdrc.soest.hawaii.edu/cgi-bin/nph-nc/data/soda/soda_sln.cdf', ...
	'http://apdrc.soest.hawaii.edu/cgi-bin/nph-nc/data/soda/soda_u.cdf', ...
	'http://apdrc.soest.hawaii.edu/cgi-bin/nph-nc/data/soda/soda_v.cdf');

% VARIABLES -- REQUIRED
LonRange = [0 360];
LatRange = [-60-((58.97+60)/127) 58.97+((58.97-60)/127)];
TimeRange = [1950 1998];
DepthRange = [0 4000];
DepthUnits = 'meters';
Resolution = 222.0;

% Force gridcat to ignore the axes popup window by forcing the axes order
axes_order = [4 3 2 1];

DataName = 'Carton Simple Ocean Data Assimilation (SODA) Beta-6';

SelectableVariables = str2mat('Sea_Temp','Salinity','Current_U','Current_V');

DodsName = str2mat( 'tmp','sln','u','v');

% note: DataNull is applied *before* scaling
DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
[DataNull(5:length(DataNull))] = deal({32766});
DataScale = [NaN NaN; ...
             NaN NaN; ...
             NaN NaN; ...
             0 5; ...
             127.6500015 0.009999999776; ...
             35.  9.999999747e-05; ...
             50. 0.009999999776; ...
		 50.  0.009999999776];

Acknowledge = ' ';

% COMMENTS

Comments = sprintf('%s\n', ...
'    model-theory: "See Carton et al (JPO Vol.30,No.2,2000 pp.294-326)"', ...
'    data-source: "ftp from nimbus04.umd.edu/pub/outgoing/cao"', ...
'    data-process: "converted to netCDF by Shen Yingshuo at IPRC"', ...
'    title: "SODA (1950-?) Monthly Sea Salinity"', ...
'    vairable: "monthly sea salinity, temperature and u and v currents"',...
		   '    Unlimited_Dimension: "time"',...
' ', ...
'  Data Server:',...
' ',...
'   IPRC SOEST',...
'   University of Hawaii',...
'   Honolulu, HI 96822',...
'   data@iprc.soest.hawaii.edu');

