% Compare_results will compare the results from the request that was just
% made to the same request made earlier.

% Begin by resetting the browser - clear selections, zoom out,
% clear R variables and clear the image.

browse('clearrange')
browse('resetcount')
browse('clrimg')

% Now get the data...

time_in = clock;

run_test = 1;
browse('getdata')

% ...and compare the results with the previous request.

eval(['load ' test_archive_name '_data'])

rlist = who('R*');
tlist = who('T*');

isbad = 0;

% Are there any returned variables. If not done.
if isempty(rlist)
  disp(['Problem with ' test_archive_name '. New list of variables is empty'])
  fprintf(fido,'        %s -- New list is empty \r\n    ', test_archive_name);
  isbad = 1;
else
  % Now check to see if only URL variable returned. If so, server probably down.
  if length(rlist) == 1
    disp(['Problem with ' test_archive_name '. Only URL variable ' rlist{1} ...
          ' returned. Server probably down.'])
    fprintf(fido,'        %s -- Only one variable returned. %s Server probably down. \r\n    ', ...
          test_archive_name, rlist{1});
    isbad = 1;
  else
    % Next make sure that list of returned variables is the same length as the saved list.
    if length(rlist) ~= length(tlist)
      disp(['Problem with ' test_archive_name '. Number of new variables'])
      disp(rlist)
      disp(' does not compare with the number of old ones')
      disp(tlist)
      disp(' ')
      fprintf(fido,'        %s -- New list does not compare with old list. \r\n        Newlist:', ...
              test_archive_name);
      for ilist=1:length(rlist)
        fprintf(fido,'  %s ', rlist{ilist});
      end
      fprintf(fido,'\r\n        Oldlist:');
      for ilist=1:length(tlist)
        fprintf(fido,'  %s ', tlist{ilist});
      end
      fprintf(fido,'\r\n    ');
      isbad = 1;
    else
      % Now run through each variable returned and compare it with the save variables.
      for itest=1:length(rlist)  % Compare the variables
      
        % Treat Acknowledgements separately; they have a time stamp in them. This must be removed.
        if eval(['strcmp(''' rlist{itest}(4:length(rlist{itest})) ''', ''Acknowledge'')'])
          eval(['nn = findstr(' rlist{itest} ',''DODS server version'');'])
          eval(['mm = findstr(' tlist{itest} ',''DODS server version'');'])
          if nn ~= mm
            disp(['Problem with ' test_archive_name '. Contents of ' rlist{itest} ' does not compare.'])
            fprintf(fido,'        %s -- Contents of %s does not compare. \r\n    ', ...
                    test_archive_name, rlist{itest});
            isbad = 1;
          else
            nlngth1 = length(rlist{itest});
            nlngth2 = length(tlist{itest});
            str1 = [rlist{itest} '(1:nn);'];
            str2 = [tlist{itest} '(1:mm);'];
            if str1 ~= str2
              disp(['Problem with ' test_archive_name '. Contents of ' rlist{itest} ' does not compare.'])
              fprintf(fido,'        %s -- Contents of %s does not compare. \r\n    ', ...
                      test_archive_name, rlist{itest});
              isbad = 1;
            end
          end
        else
        % Now check the rest of the variables.
          eval(['nn = find(isnan(' rlist{itest} '));']);
          eval([rlist{itest} '(nn) = 0;']);
          eval(['maxR = max(abs(' rlist{itest} '(:)));']);
          eval(['mm = find(isnan(' tlist{itest} '));']);
          eval([tlist{itest} '(mm) = 0;']);
          eval(['dd =' rlist{itest} '-' tlist{itest} ';']);
          mmax = max(abs(dd(:)));
          mmaxR = mmax / maxR;
          if mmaxR > 1e-13
            disp(['Problem with ' test_archive_name '. Contents of ' rlist{itest} ' does not compare.'])
            fprintf(fido,'        %s -- Contents of %s does not compare. \r\n    ', ...
                   test_archive_name, rlist{itest});
            isbad = 1;
          end
        end
      end
    end
  end
end

% Add this data set to the list of bad data sets if there was a problem.

if isbad
  bad_list = [bad_list ' ' test_archive_name];
end

time_out = clock;
if time_in(5) > time_out(5)
  time_in(5) = time_in(5) - 60;
end
dtime = (time_out(5) - time_in(5)) * 60 + time_out(6) - time_in(6);

fprintf(fido,'%5.0f   %-10s Date: %s Start: %s End: %s Duration: %4.2f s \r\n    ', ...
  run_number, test_archive_name, datestr(time_in,1), datestr(time_in,13), datestr(time_out,13), dtime);

% Get rid of junk.

clear run_test rlist tlist isbad nn mm dd itest mmin mmax
clear time_in time_out dtime nlngth1 nlngth2 str1 str2
clear R* T*
