
// (c) COPYRIGHT URI/MIT 1994-1996,1999
// Please read the full copyright statement in the file COPYRIGHT.
//
// Authors:
//      jhrg,jimg       James Gallagher (jgallagher@gso.uri.edu)
//      reza            Reza Nekovei (reza@intcomm.net)

// To hold and managed a set of open Connect *'s. 
//
// jhrg 9/30/94

#ifdef __GNUG__
#pragma implementation 
#endif

#include "config_dap.h"

#include <assert.h>

#include "debug.h"

#include "Connections.h"

using std::cerr;
using std::endl;

// private mfuncs

template <class T>
void
Connections<T>::init_array(int i)
{
    while (i--) {
	_free.prepend(i);
	_conns[i] = NULL;
    }
}

// public mfuncs

template <class T>
Connections<T>::Connections(int i)
{
    _max_con = i;

    _conns = new T[i];

    init_array(_max_con);
    DBG(cerr << "Finished Connections ctor (" << i << ")\n");
}

template <class T>
Connections<T>::Connections(const Connections<T> &cs)
{
    _max_con = cs._max_con;

    _conns = new T[_max_con];

    init_array(_max_con);
}
    
template <class T>
Connections<T>::~Connections()
{
    delete [] _conns;
    _conns = 0;
}

template <class T>
Connections<T> &
Connections<T>::operator=(const Connections<T> &rhs)
{
    if (this == &rhs)
	return *this;

    _max_con = rhs._max_con;

    _conns = new T[_max_con];

    init_array(_max_con);

    return *this;
}
    
// Given an index into the array of managed connections, return the
// corresponding Connect *.
//
// NB: Return a reference so that this will work on both the left and right
// sides of the assignement operator!
//
// Returns: A reference to the Connect *

template <class T>
T &
Connections<T>::operator[](int i)
{
    return _conns[i];
}

// Add the Connect * to the array of managed connections.
//
// Returns: integer index to Connect * or -1 if the array is full.

template <class T>
int
Connections<T>::add_connect(T c)
{
    if (_free.empty()) {
	cerr << "add_connect: too many connects, cannot add another" << endl;
	return -1;
    }

    int i = _free.remove_front(); // pop the first element

    assert(!_conns[i]);
    
    _conns[i] = c;

    return i;
}

// Remove a connection from the array of managed conections. The caller is
// responsible for deleting the Connect * BEFORE calling this member
// function.
//
// Returns: void 

template <class T>
void
Connections<T>::del_connect(int i)
{
    _free.prepend(i);
    _conns[i] = NULL;
}

// $Log: Connections.cc,v $
// Revision 1.15.4.3  2002/08/08 06:54:56  jimg
// Changes for thread-safety. In many cases I found ugly places at the
// tops of files while looking for globals, et c., and I fixed them up
// (hopefully making them easier to read, ...). Only the files RCReader.cc
// and usage.cc actually use pthreads synchronization functions. In other
// cases I removed static objects where they were used for supposed
// improvements in efficiency which had never actually been verifiied (and
// which looked dubious).
//
// Revision 1.15.4.2  2001/12/26 05:54:27  rmorris
// Make code go through the VC++ compiler.  Trivial change.
//
// Revision 1.15.4.1  2001/07/28 01:10:42  jimg
// Some of the numeric type classes did not have copy ctors or operator=.
// I added those where they were needed.
// In every place where delete (or delete []) was called, I set the pointer
// just deleted to zero. Thus if for some reason delete is called again
// before new memory is allocated there won't be a mysterious crash. This is
// just good form when using delete.
// I added calls to www2id and id2www where appropriate. The DAP now handles
// making sure that names are escaped and unescaped as needed. Connect is
// set to handle CEs that contain names as they are in the dataset (see the
// comments/Log there). Servers should not handle escaping or unescaping
// characters on their own.
//
// Revision 1.15  2000/09/22 02:17:19  jimg
// Rearranged source files so that the CVS logs appear at the end rather than
// the start. Also made the ifdef guard symbols use the same naming scheme and
// wrapped headers included in other headers in those guard symbols (to cut
// down on extraneous file processing - See Lakos).
//
// Revision 1.14  2000/08/02 22:46:48  jimg
// Merged 3.1.8
//
// Revision 1.12.6.2  2000/08/02 20:58:26  jimg
// Included the header config_dap.h in this file. config_dap.h has been
// removed from all of the DODS header files.
//
// Revision 1.13  1999/09/03 22:07:44  jimg
// Merged changes from release-3-1-1
//
// Revision 1.12.6.1  1999/08/28 06:43:04  jimg
// Fixed the implementation/interface pragmas and misc comments
//
// Revision 1.12  1999/05/04 19:47:20  jimg
// Fixed copyright statements. Removed more of the GNU classes.
//
// Revision 1.11  1999/04/29 03:04:52  jimg
// Merged ferret changes
//
// Revision 1.10.6.1  1999/04/14 22:33:46  jimg
// Removed assert() in del_connect() method. It is OK for the _conns[i] to be
// NULL when this method is called.
//
// Revision 1.10  1999/03/18 01:05:58  jimg
// Removed the assertion that checked the _conns member when operator[] was
// used. This was failing when people called close API calls (e.g., nc_close())
// more than once for a single file descriptor.
//
// Revision 1.9  1996/09/19 16:16:09  jimg
// Added some comments. Removed config_dap.h.
//
// Revision 1.8  1996/06/08 00:19:44  jimg
// Added config_dap.h in place of config_netio.h
//
// Revision 1.7  1996/05/31 23:29:31  jimg
// Updated copyright notice.
//
// Revision 1.6  1996/05/22 18:05:06  jimg
// Merged files from the old netio directory into the dap directory.
// Removed the errmsg library from the software.
//
// Revision 1.5  1995/07/09 21:20:46  jimg
// Fixed date in copyright (it now reads `Copyright 1995 ...').
//
// Revision 1.4  1995/07/09  21:14:47  jimg
// Added copyright.
//
// Revision 1.3  1995/05/22  20:43:56  jimg
// Added #include "config_netio.h"
//
// Revision 1.2  1995/04/17  03:21:45  jimg
// Added debug.h and some debugging code.
//
// Revision 1.1  1995/01/10  16:23:05  jimg
// Created new `common code' library for the net I/O stuff.
//
// Revision 1.2  1994/11/18  21:12:19  reza
// Changed it to a template class for derived classes of the Connect
//
// Revision 1.1  1994/10/05  18:02:10  jimg
// First version of the connection management classes.
// This commit also includes early versions of the test code.
//

