
// -*- C++ -*-

#include <cppunit/TextTestRunner.h>
#include <cppunit/extensions/TestFactoryRegistry.h>
#include <cppunit/extensions/HelperMacros.h>

#include <time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>

#include <string>
#include <strstream.h>

#include <Regex.h>

#include "HTTPConnect.h"
#include "RCReader.h"

using namespace CppUnit;

class HTTPConnectTest : public TestFixture {
private:
    ostrstream oss;
    streampos start_oss;
    HTTPConnect *http;

protected:
    void reset_oss() {
	oss.freeze(0);
	oss.seekp(start_oss);
    }	

    bool re_match(Regex &r, const char *s) {
	return r.match(s, strlen(s)) == (int)strlen(s);
    }



public:
    HTTPConnectTest() {}
    ~HTTPConnectTest() {}
    
    void setUp () {
	start_oss = oss.tellp();
	http = new HTTPConnect(RCReader::instance());
    }

    void tearDown() {
	delete http;
    }

    CPPUNIT_TEST_SUITE( HTTPConnectTest );

    CPPUNIT_TEST(fetch_url_test);
    CPPUNIT_TEST(server_version_test);
    CPPUNIT_TEST(type_test);

    CPPUNIT_TEST_SUITE_END();

    void fetch_url_test() {
	char c;
	try {
	    http->fetch_url("http://dcz.dods.org/");
	    FILE *stuff = http->output();
	    CPPUNIT_ASSERT(fread(&c, 1, 1, stuff) == 1 && !ferror(stuff) && !feof(stuff));

	    http->fetch_url("http://eddy.gso.uri.edu/cgi-bin/nph-dods/avhrr/2001/4/d01093165826.pvu.Z.das");
	    stuff = http->output();
	    CPPUNIT_ASSERT(fread(&c, 1, 1, stuff) == 1 && !ferror(stuff) && !feof(stuff));
	}
	catch (Error &e) {
	    cerr << "Error: " << e.get_error_message() << endl;
	    CPPUNIT_ASSERT(!"Caught a DODS exception from fetch_url");
	}
	catch (...) {
	    CPPUNIT_ASSERT(!"Caught an unknown exception from fetch_url");
	}
    }

    void server_version_test() {
	    http->fetch_url("http://eddy.gso.uri.edu/cgi-bin/nph-dods/avhrr/2001/4/d01093165826.pvu.Z.das");
	    CPPUNIT_ASSERT(http->server_version() == "dap/3.2.8");
    }

    void type_test() {
	    http->fetch_url("http://eddy.gso.uri.edu/cgi-bin/nph-dods/avhrr/2001/4/d01093165826.pvu.Z.das");
	    CPPUNIT_ASSERT(http->type() == dods_das);
    }

    void set_credentials_test() {
	http->set_credentials("jimg", "was_quit");
	try {
	    char c;
	    http->fetch_url("http://dcz.dods.org/secret");
	    FILE *stuff = http->output();
	    CPPUNIT_ASSERT(fread(&c, 1, 1, stuff) == 1 && !ferror(stuff) && !feof(stuff));
	}
	catch (...) {
	    CPPUNIT_ASSERT(!"Caught exception from fetch_url");
	}
    }
};

CPPUNIT_TEST_SUITE_REGISTRATION(HTTPConnectTest);

int 
main( int argc, char* argv[] )
{
    CppUnit::TextTestRunner runner;
    runner.addTest( CppUnit::TestFactoryRegistry::getRegistry().makeTest() );

    runner.run();

    return 0;
}

// $Log: HTTPConnectTest.cc,v $
// Revision 1.1.2.1  2002/07/25 13:24:44  jimg
// Added.
//

